searchData={"items":[{"type":"module","title":"Vix.Operator","doc":"Provides implementation of basic math operators for Vix Image.\n\nUseful to improve the readability of complex Image processing\noperation pipelines.\n\n```elixir\ndef foo do\n  use Vix.Operator\n\n  black = Operation.black!(100, 100, bands: 3)\n  white = Operation.invert!(black)\n\n  white == white + black\n  grey = black + 125  # same as [125]\n  grey = black + [125] # same as [125, 125, 125], since the image contains 3 bands\n  grey = black + [125, 125, 125]\nend\n```","ref":"Vix.Operator.html"},{"type":"function","title":"Vix.Operator.*/2","doc":"Perform multiplication operation of an image and a number, an array or\nan another image.\n\n* if argument is a number or a list of only one number, then the same number is used\n  for all image bands for the operation. Example `img * 2`, `img + [2]`\n* if array size matches image bands, then each array\n  element is added to respective band\n* if array size is more than image bands and image only contains one band\n  then the output will be a multi band image with each array element mapping\n  to one band\n* if argument is an image, then `Vix.Vips.Operation.multiply!/2` operation will\n  be performed\n\nWhen none of the argument is an image then delegates to `Kernel.*/2`","ref":"Vix.Operator.html#*/2"},{"type":"function","title":"Vix.Operator.+/2","doc":"Perform addition operation of an image and a number, an array or\nan another image.\n\n* if argument is a number or a list of only one number, then the same number is used\n  for all image bands for the operation. Example `img + 255`, `img + [255]`\n* if array size matches image bands, then each array\n  element is added to respective band. Example `red = Operation.black!(100, 100, bands: 3) + [125, 0, 0]`\n* if array size is more than image bands and image only contains one band\n  then the output will be a multi band image with each array element mapping\n  to one band\n* if argument is an image, then `Vix.Vips.Operation.add!/2` operation will\n  be performed\n\nWhen none of the argument is an image then delegates to `Kernel.+/2`","ref":"Vix.Operator.html#+/2"},{"type":"function","title":"Vix.Operator.-/2","doc":"Perform subtraction operation of an image and a number, an array or\nan another image.\n\n* if argument is a number or a list of only one number, then the same number is used\n  for all image bands for the operation. Example `img - 125`, `img - [125]`\n* if array size matches image bands, then each array\n  element is added to respective band\n* if array size is more than image bands and image only contains one band\n  then the output will be a multi band image with each array element mapping\n  to one band\n* if argument is an image, then `Vix.Vips.Operation.subtract!/2` operation will\n  be performed\n\nWhen none of the argument is an image then delegates to `Kernel.-/2`","ref":"Vix.Operator.html#-/2"},{"type":"function","title":"Vix.Operator.//2","doc":"Perform division operation of an image and a number, an array or\nan another image.\n\n* if argument is a number or a list of only one number, then the same number is used\n  for all image bands for the operation. Example `img / 2`, `img / [2]`\n* if array size matches image bands, then each array\n  element is added to respective band\n* if array size is more than image bands and image only contains one band\n  then the output will be a multi band image with each array element mapping\n  to one band\n* if argument is an image, then `Vix.Vips.Operation.divide!/2` operation will\n  be performed\n\nWhen none of the argument is an image then delegates to `Kernel.//2`","ref":"Vix.Operator.html#//2"},{"type":"module","title":"Vix.Tensor","doc":"Struct to hold raw pixel data returned by the libvips along with metadata about the binary.\n\nUseful for interoperability between other libraries like [Nx](https://hexdocs.pm/nx/Nx.html), [Evision](https://github.com/cocoa-xu/evision/).\n\nSee `Vix.Vips.Image.write_to_tensor/1` to convert an vix image to tensor.","ref":"Vix.Tensor.html"},{"type":"function","title":"Vix.Tensor.type/1","doc":"Convert Vix image pixel format to [Nx tensor type](https://hexdocs.pm/nx/Nx.Type.html#t:t/0)\n\nVix internally uses [libvips image\nformat](https://www.libvips.org/API/current/VipsImage.html#VipsBandFormat). To\nease the interoperability between Vix and other elixir libraries, we\ncan use this function.","ref":"Vix.Tensor.html#type/1"},{"type":"type","title":"Vix.Tensor.t/0","doc":"Struct to hold raw pixel data returned by the Libvips along with metadata about the binary.\n\n`:names` will always be `[:height, :width, :bands]`","ref":"Vix.Tensor.html#t:t/0"},{"type":"type","title":"Vix.Tensor.tensor_type/0","doc":"Type of the image pixel when image is represented as Tensor.\n\nThis type is useful for interoperability between different libraries. Type value is same as [`Nx.Type.t()`](https://hexdocs.pm/nx/Nx.Type.html)","ref":"Vix.Tensor.html#t:tensor_type/0"},{"type":"module","title":"Vix.Vips","doc":"Module for Vix.Vips.","ref":"Vix.Vips.html"},{"type":"function","title":"Vix.Vips.cache_get_max/0","doc":"Get the maximum number of operations we keep in cache.","ref":"Vix.Vips.html#cache_get_max/0"},{"type":"function","title":"Vix.Vips.cache_get_max_files/0","doc":"Get the maximum number of tracked files we allow before we start dropping cached operations.\n\nlibvips only tracks file descriptors it allocates, it can't track ones allocated by external libraries.","ref":"Vix.Vips.html#cache_get_max_files/0"},{"type":"function","title":"Vix.Vips.cache_get_max_mem/0","doc":"Get the maximum amount of tracked memory we allow before we start dropping cached operations.","ref":"Vix.Vips.html#cache_get_max_mem/0"},{"type":"function","title":"Vix.Vips.cache_set_max/1","doc":"Set the maximum number of operations we keep in cache.","ref":"Vix.Vips.html#cache_set_max/1"},{"type":"function","title":"Vix.Vips.cache_set_max_files/1","doc":"Set the maximum number of tracked files we allow before we start dropping cached operations.","ref":"Vix.Vips.html#cache_set_max_files/1"},{"type":"function","title":"Vix.Vips.cache_set_max_mem/1","doc":"Set the maximum amount of tracked memory we allow before we start dropping cached operations.\n\nlibvips only tracks file descriptors it allocates, it can't track ones allocated by external libraries.","ref":"Vix.Vips.html#cache_set_max_mem/1"},{"type":"function","title":"Vix.Vips.concurrency_get/0","doc":"Returns the number of worker threads that vips should use when running a VipsThreadPool.\n\nThe final value is clipped to the range 1 - 1024.","ref":"Vix.Vips.html#concurrency_get/0"},{"type":"function","title":"Vix.Vips.concurrency_set/1","doc":"Sets the number of worker threads that vips should use when running a VipsThreadPool.\n\nThe special value 0 means \"default\". In this case, the number of threads is set by the environment variable VIPS_CONCURRENCY, or if that is not set, the number of threads available on the host machine.","ref":"Vix.Vips.html#concurrency_set/1"},{"type":"function","title":"Vix.Vips.set_vips_leak_checking/1","doc":"Turn on or off vips leak checking","ref":"Vix.Vips.html#set_vips_leak_checking/1"},{"type":"function","title":"Vix.Vips.tracked_get_mem/0","doc":"Returns the number of bytes currently allocated by libvips.\n\nLibvips uses this figure to decide when to start dropping cache.","ref":"Vix.Vips.html#tracked_get_mem/0"},{"type":"function","title":"Vix.Vips.tracked_get_mem_highwater/0","doc":"Returns the largest number of bytes simultaneously allocated via libvips.\n\nHandy for estimating max memory requirements for a program.","ref":"Vix.Vips.html#tracked_get_mem_highwater/0"},{"type":"function","title":"Vix.Vips.version/0","doc":"Get installed vips version","ref":"Vix.Vips.html#version/0"},{"type":"module","title":"Vix.Vips.Image","doc":"Functions for reading and writing images as well as\naccessing and updating image metadata.","ref":"Vix.Vips.Image.html"},{"type":"module","title":"Access syntax (slicing) - Vix.Vips.Image","doc":"Vix images implement Elixir's access syntax. This allows developers\nto slice images and easily access sub-dimensions and values.","ref":"Vix.Vips.Image.html#module-access-syntax-slicing"},{"type":"module","title":"Integer - Vix.Vips.Image","doc":"Access accepts integers. Integers will extract an image band using parameter as index:\n\n    #=> {:ok, i} = Image.new_from_file(\"./test/images/puppies.jpg\")\n    {:ok, %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153539>}}\n    #=> i[0]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153540>}\n\nIf a negative index is given, it accesses the band from the back:\n\n    #=> i[-1]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153540>}\n\nOut of bound access will throw an `ArgumentError` exception:\n\n    #=> i[-4]\n    ** (ArgumentError) Invalid band requested. Found -4","ref":"Vix.Vips.Image.html#module-integer"},{"type":"module","title":"Range - Vix.Vips.Image","doc":"Access also accepts ranges. Ranges in Elixir are inclusive:\n\n    #=> i[0..1]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153641>}\n\nRanges can receive negative positions and they will read from\nthe back. In such cases, the range step must be explicitly given\n(on Elixir 1.12 and later) and the right-side of the range must\nbe equal or greater than the left-side:\n\n    #=> i[0..-1//1]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153703>}\n\nTo slice across multiple dimensions, you can wrap the ranges in a list.\nThe list will be of the form `[with_slice, height_slice, band_slice]`.\n\n    # Returns an image that slices a 10x10 pixel square\n    # from the top left of the image with three bands\n    #=> i[[0..9, 0..9, 0..3]]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153738>}\n\nIf number of dimensions are less than 3 then remaining dimensions\nare returned in full\n\n    # If `i` size is 100x100 with 3 bands\n    #=> i[[0..9, 0..9]] # equivalent to `i[[0..9, 0..9, 0..2]]`\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153740>}\n\n    #=> i[[0..9]] # equivalent to `i[[0..9, 0..99, 0..2]]`\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153703>}\n\nSlices can include negative ranges in which case the indexes\nare calculated from the right and bottom of the image.\n\n    # Slices the bottom right 10x10 pixels of the image\n    # and returns all bands.\n    #=> i[[-10..-1, -10..-1]]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153742>}\n\nSlice can mix integers and ranges\n\n    # Slices the bottom right 10x1 pixels of the image\n    # and returns all bands.\n    #=> i[[-10..-1, -1]]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153742>}","ref":"Vix.Vips.Image.html#module-range"},{"type":"module","title":"Keyword List - Vix.Vips.Image","doc":"Access also accepts keyword list. Where key can be any of `width`,\n`height`, `band`.  and value must be an `integer`, `range`. This is\nuseful for complex scenarios when you want omit dimensions arbitrary\ndimensions.\n\n    # Slices an image with height 10 with max width and all bands\n    #=> i[[height: 0..10]]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153742>}\n\n    # Slices an image with single band 1\n    #=> i[[band: 1]]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153742>}\n\n    # Slices the bottom right 10x10 pixels of the image\n    # and returns all bands.\n    #=> i[[width: -10..-1, height: -10..-1]]\n    %Vix.Vips.Image{ref: #Reference<0.2448791511.2685009949.153742>}","ref":"Vix.Vips.Image.html#module-keyword-list"},{"type":"function","title":"Vix.Vips.Image.bands/1","doc":"Get \"bands\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-bands) for more details regarding `bands` function","ref":"Vix.Vips.Image.html#bands/1"},{"type":"function","title":"Vix.Vips.Image.coding/1","doc":"Get \"coding\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-coding) for more details regarding `coding` function","ref":"Vix.Vips.Image.html#coding/1"},{"type":"function","title":"Vix.Vips.Image.filename/1","doc":"Get \"filename\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-filename) for more details regarding `filename` function","ref":"Vix.Vips.Image.html#filename/1"},{"type":"function","title":"Vix.Vips.Image.format/1","doc":"Get \"format\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-format) for more details regarding `format` function","ref":"Vix.Vips.Image.html#format/1"},{"type":"function","title":"Vix.Vips.Image.get_pixel/3","doc":"Returns the pixel value for the passed position\n\nPixel value is a list of numbers. Size of the list depends on the\nnumber of bands in the image and number type will depend on the\nband format (see: `t:Vix.Vips.Operation.vips_band_format/0`).\n\nFor example for RGBA image with unsigned char band format the\nreturn value will be a list of integer of size 4.\n\nThis function is similar to `Vix.Vips.Operation.getpoint/3`,\ngetpoint always returns the value as `float` but get_pixel returns\nbased on the image band format.\n\n> #### Caution {: .warning}\n> Loop through lot of pixels using `get_pixel` can be expensive.\n> Use `extract_area` or Access syntax (slicing) instead","ref":"Vix.Vips.Image.html#get_pixel/3"},{"type":"function","title":"Vix.Vips.Image.get_pixel!/3","doc":"Same as `get_pixel/3`. Returns the pixel value on success or raise the error.","ref":"Vix.Vips.Image.html#get_pixel!/3"},{"type":"function","title":"Vix.Vips.Image.has_alpha?/1","doc":"Return a boolean indicating if an image has an alpha band.\n\nExample\n\n```elixir\n  {:ok, im} = Image.new_from_file(\"puppies.jpg\")\n\n  has_alpha? = Image.has_alpha?(im)\n```","ref":"Vix.Vips.Image.html#has_alpha?/1"},{"type":"function","title":"Vix.Vips.Image.header_field_names/1","doc":"Get all image header field names.\n\nSee https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-fields for more details","ref":"Vix.Vips.Image.html#header_field_names/1"},{"type":"function","title":"Vix.Vips.Image.header_value/2","doc":"Get image header value.\n\nThis is a generic function to get header value.\n\nCasts the value to appropriate type. Returned value can be integer, float, string, binary, list. Use `Vix.Vips.Image.header_value_as_string/2` to get string representation of any header value.\n\n```elixir\n{:ok, width} = Image.header_value(vips_image, \"width\")\n```","ref":"Vix.Vips.Image.html#header_value/2"},{"type":"function","title":"Vix.Vips.Image.header_value_as_string/2","doc":"Get image header value as string.\n\nThis is generic method to get string representation of a header value. If value is VipsBlob, then it returns base64 encoded data.\n\nSee: https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-as-string","ref":"Vix.Vips.Image.html#header_value_as_string/2"},{"type":"function","title":"Vix.Vips.Image.headers/1","doc":"Get all image header data as map. Headers includes metadata such as image height, width, bands.\n\nIf a header does not exists then value for that header will be set to `nil`.\n\nSee https://libvips.github.io/libvips/API/current/libvips-header.html for more details.","ref":"Vix.Vips.Image.html#headers/1"},{"type":"function","title":"Vix.Vips.Image.height/1","doc":"Get \"height\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-height) for more details regarding `height` function","ref":"Vix.Vips.Image.html#height/1"},{"type":"function","title":"Vix.Vips.Image.interpretation/1","doc":"Get \"interpretation\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-interpretation) for more details regarding `interpretation` function","ref":"Vix.Vips.Image.html#interpretation/1"},{"type":"function","title":"Vix.Vips.Image.mode/1","doc":"Get \"mode\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-mode) for more details regarding `mode` function","ref":"Vix.Vips.Image.html#mode/1"},{"type":"function","title":"Vix.Vips.Image.mutate/2","doc":"Mutate an image in-place. You have to pass a function which takes MutableImage as argument. Inside the callback function, you can call functions which modify the image, such as setting or removing metadata. See `Vix.Vips.MutableImage`\n\nReturn value of the callback must be one of:\n\n* The mutated image passed to the callback or\n* `:ok` or\n* `{:ok, some_result}`\n\nCall returns updated image.\n\nExample\n\n```elixir\n  {:ok, im} = Image.new_from_file(\"puppies.jpg\")\n\n  {:ok, new_im} =\n    Image.mutate(im, fn mut_image ->\n      :ok = MutableImage.update(mut_image, \"orientation\", 0)\n      :ok = MutableImage.set(mut_image, \"new-field\", :gint, 0)\n    end)\n```","ref":"Vix.Vips.Image.html#mutate/2"},{"type":"function","title":"Vix.Vips.Image.n_pages/1","doc":"Get \"n-pages\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-n-pages) for more details regarding `n_pages` function","ref":"Vix.Vips.Image.html#n_pages/1"},{"type":"function","title":"Vix.Vips.Image.new_from_binary/5","doc":"Create a new image from raw pixel data\n\nCreates an image by wrapping passed raw pixel data. This function\ndoes not copy the passed binary, instead it just creates a reference\nto the binary term (zero-copy). So this function is very efficient.\n\nThis function is useful when you are getting raw pixel data from\nsome other library like\n[`eVision`](https://github.com/cocoa-xu/evision) or\n[`Nx`](https://github.com/elixir-nx/) and want to perform some\noperation on it using Vix.\n\nBinary should be sequence of pixel data, for example: RGBRGBRGB. and\norder should be left-to-right, top-to-bottom.\n\n`bands` should be number values which represent the each pixel. For\nexample: if each pixel is RGB then `bands` will be 3. If each pixel\nis RGBA then `bands` will be 4.  `band_format` refers to type of\neach band. Usually it will be `:VIPS_FORMAT_UCHAR`.\n\n`bin` should be raw pixel data binary. For loading\nformatted binary (JPEG, PNG) see `new_from_buffer/2`.\n\n##  Endianness\n\nByte order of the data *must* be in native endianness. This matters\nif you are generating or manipulating binary by using bitstring\nsyntax. By default bitstring treat binary byte order as `big` endian\nwhich might *not* be native. Always use `native` specifier to\nensure. See [Elixir\ndocs](https://hexdocs.pm/elixir/Kernel.SpecialForms.html#%3C%3C%3E%3E/1-endianness)\nfor more details.","ref":"Vix.Vips.Image.html#new_from_binary/5"},{"type":"function","title":"Vix.Vips.Image.new_from_buffer/2","doc":"Create a new image from formatted binary\n\nCreate a new image from formatted binary `bin`. Binary should be an\nimage encoded in a format such as JPEG. It tries to recognize the\nformat by checking the binary.\n\nIf you already know the image format of `bin` then you can just use\ncorresponding loader operation function directly from\n`Vix.Vips.Operation` instead. For example to load jpeg, you can use\n`Vix.Vips.Operation.jpegload_buffer/2`\n\n`bin` should be formatted binary (ie. JPEG, PNG etc). For loading\nunformatted binary (raw pixel data) see `new_from_binary/5`.\n\nOptional param `opts` is passed to the image loader. Options\navailable depend on the file format. You can find all options\navailable like this:\n\n```sh\n$ vips jpegload_buffer\n```\n\nNot all loaders support load from buffer, but at least JPEG, PNG and\nTIFF images will work.","ref":"Vix.Vips.Image.html#new_from_buffer/2"},{"type":"function","title":"Vix.Vips.Image.new_from_enum/2","doc":"Create a new image from Enumerable.\n\nReturns an image which will lazily pull data from passed\nEnumerable. `enum` should be stream of bytes of an encoded image\nsuch as JPEG. This functions recognizes the image format and\nmetadata by reading starting bytes and wraps passed Enumerable as an\nimage. Remaining bytes are read on-demand.\n\nUseful when working with big images. Where you don't want to load\ncomplete input image data to memory.\n\n```elixir\n{:ok, image} =\n  File.stream!(\"puppies.jpg\", [], 1024) # or read from s3, web-request\n  |> Image.new_from_enum()\n\n:ok = Image.write_to_file(image, \"puppies.png\")\n```\n\nOptional param `opts` string is passed to the image loader. It is a string\nof the format \"[name=value,...]\".\n\n```elixir\nImage.new_from_enum(stream, \"[shrink=2]\")\n```\n\nWill read the stream with downsampling by a factor of two.\n\nThe full set of options available depend upon the image format. You\ncan find all options available at the command-line. To see a summary\nof the available options for the JPEG loader:\n\n```shell\n$ vips jpegload_source\n```","ref":"Vix.Vips.Image.html#new_from_enum/2"},{"type":"function","title":"Vix.Vips.Image.new_from_file/2","doc":"Opens `path` for reading, returns an instance of `t:Vix.Vips.Image.t/0`\n\nIt can load files in many image formats, including VIPS, TIFF, PNG,\nJPEG, FITS, Matlab, OpenEXR, CSV, WebP, Radiance, RAW, PPM and\nothers.\n\nOptional param `opts` is passed to the image loader. Available\noptions depends on the file format. You can find all options\navailable for a format under operation function in\n[Operation](./search.html?q=load+-buffer+-filename+-profile) module.\n\nFor example, you can find all of the options supported by\nJPEG under `Vix.Vips.Operation.jpegload/2` function documentation.\n\n```elixir\nImage.new_from_file(\"fred.jpg\", shrink: 2)\n```\n\nOpens \"fred.jpg\", downsampling by a factor of two.\n\n> #### Loading is fast {: .info}\n> Only enough of the image is loaded to the memory to be able to\n> fill out the header. Pixels will only be decompressed when they are\n> needed.\n\nIf you want more control over the loader, Use the specific format loader\nfrom `Vix.Vips.Operation`. For example for jpeg use\n`Vix.Vips.Operation.jpegload/2`","ref":"Vix.Vips.Image.html#new_from_file/2"},{"type":"function","title":"Vix.Vips.Image.new_from_image/2","doc":"Create a new image based on an existing image with each pixel set to `value`\n\nCreates a new image with width, height, format, interpretation,\nresolution and offset taken from the input image, but with each band\nset from `value`.","ref":"Vix.Vips.Image.html#new_from_image/2"},{"type":"function","title":"Vix.Vips.Image.new_from_list/2","doc":"Make a VipsImage from 1D or 2D list.\n\nIf list is a single dimension then an image of height 1 will be with list\ncontent as values.\n\nIf list is 2D then 2D image will be created.\n\nOutput image will always be a one band image with `double` format.\n\n```elixir\n# 1D list\n{:ok, img2} = Image.new_from_list([0, 1, 0])\n\n# 2D list\n{:ok, img} = Image.new_from_list([[0, 1, 0], [1, 1, 1], [0, 1, 0]])\n```","ref":"Vix.Vips.Image.html#new_from_list/2"},{"type":"function","title":"Optional - Vix.Vips.Image.new_from_list/2","doc":"* scale - Default: 1\n* offset - Default: 0","ref":"Vix.Vips.Image.html#new_from_list/2-optional"},{"type":"function","title":"Vix.Vips.Image.new_matrix_from_array/4","doc":"Make a VipsImage from 2D list.\n\nThis is a convenience function makes an image which is a matrix: a one-band VIPS_FORMAT_DOUBLE image held in memory. Useful for vips operations such as `conv`.\n\n```elixir\n{:ok, mask} = Image.new_matrix_from_array(3, 3, [[0, 1, 0], [1, 1, 1], [0, 1, 0]])\n```","ref":"Vix.Vips.Image.html#new_matrix_from_array/4"},{"type":"function","title":"Optional - Vix.Vips.Image.new_matrix_from_array/4","doc":"* scale - Default: 1\n* offset - Default: 0","ref":"Vix.Vips.Image.html#new_matrix_from_array/4-optional"},{"type":"function","title":"Vix.Vips.Image.new_temp_file/1","doc":"Make a VipsImage which, when written to, will create a temporary file on disc.\n\nThe file will be automatically deleted when the image is destroyed. format is something like `\"%s.v\"` for a vips file.\n\nThe file is created in the temporary directory. This is set with the environment variable TMPDIR. If this is not set, then on Unix systems, vips will default to `/tmp`. On Windows, vips uses `GetTempPath()` to find the temporary directory.\n\n```elixir\nvips_image = Image.new_temp_file(\"%s.v\")\n```","ref":"Vix.Vips.Image.html#new_temp_file/1"},{"type":"function","title":"Vix.Vips.Image.offset/1","doc":"Get \"offset\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-offset) for more details regarding `offset` function","ref":"Vix.Vips.Image.html#offset/1"},{"type":"function","title":"Vix.Vips.Image.orientation/1","doc":"Get \"orientation\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-orientation) for more details regarding `orientation` function","ref":"Vix.Vips.Image.html#orientation/1"},{"type":"function","title":"Vix.Vips.Image.page_height/1","doc":"Get \"page-height\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-page-height) for more details regarding `page_height` function","ref":"Vix.Vips.Image.html#page_height/1"},{"type":"function","title":"Vix.Vips.Image.scale/1","doc":"Get \"scale\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-scale) for more details regarding `scale` function","ref":"Vix.Vips.Image.html#scale/1"},{"type":"function","title":"Vix.Vips.Image.supported_saver_suffixes/0","doc":"Returns list of supported extension for *saving* the image.\n\nSupported suffix can be used to save image in a particular format.\nSee `write_to_file/2`.\n\nNote that the image format supported for saving the image and the\nformat supported for loading image might be different. For example\nSVG format can be loaded but can not be saved.","ref":"Vix.Vips.Image.html#supported_saver_suffixes/0"},{"type":"function","title":"Vix.Vips.Image.to_list/1","doc":"Converts an Image to a nested list.\n\nReturns a nested list of the shape `height x width x band`.\nFor example for an image with height 10, width 5, and 3 bands\nreturned value will be a list of length 10 (height), with each\nelement will be a list of length 5 (height), and each\nelement inside that will be a list of length 3 (bands).\n\n\n> #### Caution {: .warning}\n> This is meant to be used for very small images such as histograms, and\n> matrix. Depending on the image size it can generate and return a large\n> list leading to performance issues.\n\n\n```elixir\nhistogram =\n  Vix.Vips.Operation.black!(10, 50)\n  |> Vix.Vips.Operation.hist_find!()\n\nlist = Vix.Vips.Image.to_list(histogram)\n```","ref":"Vix.Vips.Image.html#to_list/1"},{"type":"function","title":"Vix.Vips.Image.width/1","doc":"Get \"width\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-width) for more details regarding `width` function","ref":"Vix.Vips.Image.html#width/1"},{"type":"function","title":"Vix.Vips.Image.write_to_binary/1","doc":"Returns raw pixel data of the image as binary term\n\nPlease check `write_to_tensor` for more details. This function just\nreturns the data instead of the `Vix.Tensor` struct.\n\nPrefer using `write_to_tensor` instead of this function. This is\nonly useful if you already know the details about the returned\nbinary blob. Such as height, width and bands.","ref":"Vix.Vips.Image.html#write_to_binary/1"},{"type":"function","title":"Vix.Vips.Image.write_to_buffer/2","doc":"Returns `vips_image` as binary based on the format specified by `suffix`.\n\nThis function is similar to `write_to_file` but instead of writing\nthe output to the file, it returns it as a binary.\n\nCurrently only TIFF, JPEG and PNG formats are supported.\n\nSave options may be encoded in the filename. For example:\n\n```elixir\nImage.write_to_buffer(vips_image, \".jpg[Q=90]\")\n```\n\nThe full set of save options depend on the selected saver. You can\nget list of available options for the saver\n\n```shell\n$ vips jpegsave\n```","ref":"Vix.Vips.Image.html#write_to_buffer/2"},{"type":"function","title":"Vix.Vips.Image.write_to_file/2","doc":"Write `vips_image` to a file.\n\nA saver is selected based on image extension in `path`. You can\nget list of supported extensions by `supported_saver_suffixes/0`.\n\nSave options may be encoded in the filename. For example:\n\n```elixir\nImage.write_to_file(vips_image, \"fred.jpg[Q=90]\")\n```\n\nThe full set of save options depend on the selected saver.\nYou can check the supported options for a saver by checking\ndocs for the particular format save function in `Operation` module.\nFor example, for you jpeg, `Vix.Vips.Operation.jpegsave/2`.\n\n\nIf you want more control over the saver, Use specific format saver\nfrom `Vix.Vips.Operation`. For example for jpeg use\n`Vix.Vips.Operation.jpegsave/2`","ref":"Vix.Vips.Image.html#write_to_file/2"},{"type":"function","title":"Vix.Vips.Image.write_to_stream/2","doc":"Creates a Stream from Image.\n\nReturns a Stream which will lazily pull data from passed image.\n\nUseful when working with big images. Where you don't want to keep\ncomplete output image in memory.\n\n\n```elixir\n{:ok, image} = Image.new_from_file(\"puppies.jpg\")\n\n:ok =\n  Image.write_to_stream(image, \".png\")\n  |> Stream.into(File.stream!(\"puppies.png\")) # or write to S3, web-request\n  |> Stream.run()\n```\n\nSecond param `suffix` determines the format of the output\nstream. Save options may be appended to the suffix as\n\"[name=value,...]\".\n\n```elixir\nImage.write_to_stream(vips_image, \".jpg[Q=90]\")\n```\n\nOptions are specific to save operation. You can find out all\navailable options for the save operation at command line. For\nexample:\n\n```shell\n$ vips jpegsave_target\n```","ref":"Vix.Vips.Image.html#write_to_stream/2"},{"type":"function","title":"Vix.Vips.Image.write_to_tensor/1","doc":"Returns raw pixel data of the image as `Vix.Tensor`\n\nVIPS images are three-dimensional arrays, the dimensions being\nwidth, height and bands.\n\nEach dimension can be up to 2 ** 31 pixels (or band elements).\nAn image has a format, meaning the machine number type used to\nrepresent each value. VIPS supports 10 formats, from 8-bit unsigned\ninteger up to 128-bit double complex.\n\nIn VIPS, images are uninterpreted arrays, meaning that from\nthe point of view of most operations, they are just large\ncollections of numbers. There's no difference between an RGBA\n(RGB with alpha) image and a CMYK image, for example, they are\nboth just four-band images.\n\nThis function is intended to support interoperability of image\ndata between different libraries.  Since the array is created as\na NIF resource it will be correctly garbage collected when\nthe last reference falls out of scope.\n\nLibvips might run all the operations to produce the pixel data\ndepending on the caching mechanism and how image is built.\n\n##  Endianness\n\nReturned binary term will be in native endianness. By default\nbitstring treats byte order as `big` endian which might *not* be\nnative. Always use `native` specifier to ensure. See [Elixir\ndocs](https://hexdocs.pm/elixir/Kernel.SpecialForms.html#%3C%3C%3E%3E/1-endianness)\nfor more details.","ref":"Vix.Vips.Image.html#write_to_tensor/1"},{"type":"function","title":"Vix.Vips.Image.xoffset/1","doc":"Get \"xoffset\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-xoffset) for more details regarding `xoffset` function","ref":"Vix.Vips.Image.html#xoffset/1"},{"type":"function","title":"Vix.Vips.Image.xres/1","doc":"Get \"xres\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-xres) for more details regarding `xres` function","ref":"Vix.Vips.Image.html#xres/1"},{"type":"function","title":"Vix.Vips.Image.yoffset/1","doc":"Get \"yoffset\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-yoffset) for more details regarding `yoffset` function","ref":"Vix.Vips.Image.html#yoffset/1"},{"type":"function","title":"Vix.Vips.Image.yres/1","doc":"Get \"yres\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-yres) for more details regarding `yres` function","ref":"Vix.Vips.Image.html#yres/1"},{"type":"type","title":"Vix.Vips.Image.t/0","doc":"Represents an instance of VipsImage","ref":"Vix.Vips.Image.html#t:t/0"},{"type":"module","title":"Vix.Vips.Interpolate","doc":"Make interpolators for operators like `affine` and `mapim`.","ref":"Vix.Vips.Interpolate.html"},{"type":"function","title":"Vix.Vips.Interpolate.new/1","doc":"Make a new interpolator by name.\n\nMake a new interpolator from the libvips class nickname. For example:\n\n```elixir\n{:ok, interpolate} = Interpolate.new(\"bilindear\")\n```\n\nYou can get a list of all supported interpolators from the command-line with:\n\n```shell\n$ vips -l interpolate\n```\n\nSee for example `affine`.","ref":"Vix.Vips.Interpolate.html#new/1"},{"type":"function","title":"Vix.Vips.Interpolate.new!/1","doc":"Make a new interpolator by name.\n\nMake a new interpolator from the libvips class nickname. For example:\n\n```elixir\ninterpolate = Interpolate.new!(\"bilindear\")\n```\n\nYou can get a list of all supported interpolators from the command-line with:\n\n```shell\n$ vips -l interpolate\n```\n\nSee for example `affine`.","ref":"Vix.Vips.Interpolate.html#new!/1"},{"type":"type","title":"Vix.Vips.Interpolate.t/0","doc":"Represents an instance of VipsInterpolate","ref":"Vix.Vips.Interpolate.html#t:t/0"},{"type":"module","title":"Vix.Vips.MutableImage","doc":"Vips Mutable Image\n\nSee `Vix.Vips.Image.mutate/2`","ref":"Vix.Vips.MutableImage.html"},{"type":"function","title":"Vix.Vips.MutableImage.bands/1","doc":"Return the number of bands of a mutable image.","ref":"Vix.Vips.MutableImage.html#bands/1"},{"type":"function","title":"Vix.Vips.MutableImage.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Vix.Vips.MutableImage.html#child_spec/1"},{"type":"function","title":"Vix.Vips.MutableImage.get/2","doc":"Returns metadata from the image","ref":"Vix.Vips.MutableImage.html#get/2"},{"type":"function","title":"Vix.Vips.MutableImage.has_alpha?/1","doc":"Return a boolean indicating if a mutable image\nhas an alpha band.","ref":"Vix.Vips.MutableImage.html#has_alpha?/1"},{"type":"function","title":"Vix.Vips.MutableImage.height/1","doc":"Return the height of a mutable image.","ref":"Vix.Vips.MutableImage.html#height/1"},{"type":"function","title":"Vix.Vips.MutableImage.remove/2","doc":"Remove a metadata item from an image.","ref":"Vix.Vips.MutableImage.html#remove/2"},{"type":"function","title":"Vix.Vips.MutableImage.set/4","doc":"Create a metadata item on an image of the specified type.\nVix converts value to specified GType\n\nSupported GTypes\n  * `:gint`\n  * `:guint`\n  * `:gdouble`\n  * `:gboolean`\n  * `:gchararray`\n  * `:VipsArrayInt`\n  * `:VipsArrayDouble`\n  * `:VipsArrayImage`\n  * `:VipsRefString`\n  * `:VipsBlob`\n  * `:VipsImage`\n  * `:VipsInterpolate`","ref":"Vix.Vips.MutableImage.html#set/4"},{"type":"function","title":"Vix.Vips.MutableImage.shape/1","doc":"Return the shape of the image as\n`{width, height, bands}`.","ref":"Vix.Vips.MutableImage.html#shape/1"},{"type":"function","title":"Vix.Vips.MutableImage.update/3","doc":"Set the value of existing metadata item on an image. Value is converted to match existing value GType","ref":"Vix.Vips.MutableImage.html#update/3"},{"type":"function","title":"Vix.Vips.MutableImage.width/1","doc":"Return the width of a mutable image.","ref":"Vix.Vips.MutableImage.html#width/1"},{"type":"type","title":"Vix.Vips.MutableImage.t/0","doc":"Represents a mutable instance of VipsImage","ref":"Vix.Vips.MutableImage.html#t:t/0"},{"type":"module","title":"Vix.Vips.MutableOperation","doc":"Module for Vix.Vips.MutableOperation.","ref":"Vix.Vips.MutableOperation.html"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_circle/6","doc":"Draw a circle on an image","ref":"Vix.Vips.MutableOperation.html#draw_circle/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_circle/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * cx - Centre of draw_circle\n  * cy - Centre of draw_circle\n  * radius - Radius in pixels","ref":"Vix.Vips.MutableOperation.html#draw_circle/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_circle/6","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_circle/6-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_circle!/6","doc":"Draw a circle on an image","ref":"Vix.Vips.MutableOperation.html#draw_circle!/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_circle!/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * cx - Centre of draw_circle\n  * cy - Centre of draw_circle\n  * radius - Radius in pixels","ref":"Vix.Vips.MutableOperation.html#draw_circle!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_circle!/6","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_circle!/6-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_flood/5","doc":"Flood-fill an area","ref":"Vix.Vips.MutableOperation.html#draw_flood/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_flood/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x - DrawFlood start point\n  * y - DrawFlood start point","ref":"Vix.Vips.MutableOperation.html#draw_flood/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_flood/5","doc":"* equal - DrawFlood while equal to edge. Default: `false`\n* test - Test pixels in this image.","ref":"Vix.Vips.MutableOperation.html#draw_flood/5-optional"},{"type":"function","title":"Returns - Vix.Vips.MutableOperation.draw_flood/5","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* height - Height of modified area. (`integer()`)\n* width - Width of modified area. (`integer()`)\n* top - Top edge of modified area. (`integer()`)\n* left - Left edge of modified area. (`integer()`)","ref":"Vix.Vips.MutableOperation.html#draw_flood/5-returns"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_flood!/5","doc":"Flood-fill an area","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_flood!/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x - DrawFlood start point\n  * y - DrawFlood start point","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_flood!/5","doc":"* equal - DrawFlood while equal to edge. Default: `false`\n* test - Test pixels in this image.","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5-optional"},{"type":"function","title":"Returns - Vix.Vips.MutableOperation.draw_flood!/5","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* height - Height of modified area. (`integer()`)\n* width - Width of modified area. (`integer()`)\n* top - Top edge of modified area. (`integer()`)\n* left - Left edge of modified area. (`integer()`)","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5-returns"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_image/5","doc":"Paint an image into another image","ref":"Vix.Vips.MutableOperation.html#draw_image/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_image/5","doc":"* image - Image to draw on\n  * sub - Sub-image to insert into main image\n  * x - Draw image here\n  * y - Draw image here","ref":"Vix.Vips.MutableOperation.html#draw_image/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_image/5","doc":"* mode - Combining mode. Default: `:VIPS_COMBINE_MODE_SET`","ref":"Vix.Vips.MutableOperation.html#draw_image/5-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_image!/5","doc":"Paint an image into another image","ref":"Vix.Vips.MutableOperation.html#draw_image!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_image!/5","doc":"* image - Image to draw on\n  * sub - Sub-image to insert into main image\n  * x - Draw image here\n  * y - Draw image here","ref":"Vix.Vips.MutableOperation.html#draw_image!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_image!/5","doc":"* mode - Combining mode. Default: `:VIPS_COMBINE_MODE_SET`","ref":"Vix.Vips.MutableOperation.html#draw_image!/5-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_line/6","doc":"Draw a line on an image","ref":"Vix.Vips.MutableOperation.html#draw_line/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_line/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x1 - Start of draw_line\n  * y1 - Start of draw_line\n  * x2 - End of draw_line\n  * y2 - End of draw_line","ref":"Vix.Vips.MutableOperation.html#draw_line/6-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_line!/6","doc":"Draw a line on an image","ref":"Vix.Vips.MutableOperation.html#draw_line!/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_line!/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x1 - Start of draw_line\n  * y1 - Start of draw_line\n  * x2 - End of draw_line\n  * y2 - End of draw_line","ref":"Vix.Vips.MutableOperation.html#draw_line!/6-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_mask/5","doc":"Draw a mask on an image","ref":"Vix.Vips.MutableOperation.html#draw_mask/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_mask/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * mask - Mask of pixels to draw\n  * x - Draw mask here\n  * y - Draw mask here","ref":"Vix.Vips.MutableOperation.html#draw_mask/5-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_mask!/5","doc":"Draw a mask on an image","ref":"Vix.Vips.MutableOperation.html#draw_mask!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_mask!/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * mask - Mask of pixels to draw\n  * x - Draw mask here\n  * y - Draw mask here","ref":"Vix.Vips.MutableOperation.html#draw_mask!/5-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_rect/7","doc":"Paint a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_rect/7"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_rect/7","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_rect/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_rect/7","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_rect/7-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_rect!/7","doc":"Paint a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_rect!/7"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_rect!/7","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_rect!/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_rect!/7","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_rect!/7-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_smudge/5","doc":"Blur a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_smudge/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_smudge/5","doc":"* image - Image to draw on\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_smudge/5-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_smudge!/5","doc":"Blur a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_smudge!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_smudge!/5","doc":"* image - Image to draw on\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_smudge!/5-arguments"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_access/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_access/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_align/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_align/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_angle45/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_angle45/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_angle/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_angle/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_band_format/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_band_format/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_blend_mode/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_blend_mode/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_coding/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_coding/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_combine/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_combine/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_combine_mode/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_combine_mode/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_compass_direction/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_compass_direction/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_demand_style/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_demand_style/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_direction/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_direction/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_extend/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_extend/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_fail_on/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_fail_on/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_dz_container/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_dz_container/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_dz_depth/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_dz_depth/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_dz_layout/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_dz_layout/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_flags/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_flags/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_heif_compression/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_heif_compression/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_heif_encoder/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_heif_encoder/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_keep/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_keep/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_png_filter/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_png_filter/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_subsample/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_subsample/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_tiff_compression/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_tiff_compression/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_tiff_predictor/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_tiff_predictor/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_tiff_resunit/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_tiff_resunit/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_webp_preset/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_webp_preset/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_intent/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_intent/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_interesting/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_interesting/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_interpretation/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_interpretation/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_kernel/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_kernel/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_boolean/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_boolean/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_complex2/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_complex2/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_complex/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_complex/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_complexget/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_complexget/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_math2/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_math2/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_math/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_math/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_morphology/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_morphology/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_relational/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_relational/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_round/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_round/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_pcs/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_pcs/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_precision/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_precision/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_region_shrink/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_region_shrink/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_size/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_size/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_text_wrap/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_text_wrap/0"},{"type":"module","title":"Vix.Vips.Operation","doc":"Vips Operations\n\nSee libvips\n[documentation](https://libvips.github.io/libvips/API/current/func-list.html)\nfor more detailed description of the operation.\n\nVips operation functions are generated using vips-introspection and\nare up-to-date with libvips version installed. Documentation in the\nhexdocs might *not* match for you.","ref":"Vix.Vips.Operation.html"},{"type":"function","title":"Vix.Vips.Operation.abs/1","doc":"Absolute value of an image","ref":"Vix.Vips.Operation.html#abs/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.abs/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#abs/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.abs!/1","doc":"Absolute value of an image","ref":"Vix.Vips.Operation.html#abs!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.abs!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#abs!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.add/2","doc":"Add two images","ref":"Vix.Vips.Operation.html#add/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.add/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#add/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.add!/2","doc":"Add two images","ref":"Vix.Vips.Operation.html#add!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.add!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#add!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.affine/3","doc":"Affine transform of an image","ref":"Vix.Vips.Operation.html#affine/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.affine/3","doc":"* input - Input image argument\n  * matrix - Transformation matrix","ref":"Vix.Vips.Operation.html#affine/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.affine/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* oarea - Area of output to generate. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#affine/3-optional"},{"type":"function","title":"Vix.Vips.Operation.affine!/3","doc":"Affine transform of an image","ref":"Vix.Vips.Operation.html#affine!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.affine!/3","doc":"* input - Input image argument\n  * matrix - Transformation matrix","ref":"Vix.Vips.Operation.html#affine!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.affine!/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* oarea - Area of output to generate. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#affine!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.arrayjoin/2","doc":"Join an array of images","ref":"Vix.Vips.Operation.html#arrayjoin/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.arrayjoin/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#arrayjoin/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.arrayjoin/2","doc":"* vspacing - Vertical spacing between images. Default: `1`\n* hspacing - Horizontal spacing between images. Default: `1`\n* valign - Align on the top, centre or bottom. Default: `:VIPS_ALIGN_LOW`\n* halign - Align on the left, centre or right. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* across - Number of images across grid. Default: `1`","ref":"Vix.Vips.Operation.html#arrayjoin/2-optional"},{"type":"function","title":"Vix.Vips.Operation.arrayjoin!/2","doc":"Join an array of images","ref":"Vix.Vips.Operation.html#arrayjoin!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.arrayjoin!/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#arrayjoin!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.arrayjoin!/2","doc":"* vspacing - Vertical spacing between images. Default: `1`\n* hspacing - Horizontal spacing between images. Default: `1`\n* valign - Align on the top, centre or bottom. Default: `:VIPS_ALIGN_LOW`\n* halign - Align on the left, centre or right. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* across - Number of images across grid. Default: `1`","ref":"Vix.Vips.Operation.html#arrayjoin!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.autorot/1","doc":"Autorotate image by exif tag","ref":"Vix.Vips.Operation.html#autorot/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.autorot/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#autorot/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.autorot/1","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flip - Whether the image was flipped or not. (`boolean()`)\n* angle - Angle image was rotated by. (`vips_angle`)","ref":"Vix.Vips.Operation.html#autorot/1-returns"},{"type":"function","title":"Vix.Vips.Operation.autorot!/1","doc":"Autorotate image by exif tag","ref":"Vix.Vips.Operation.html#autorot!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.autorot!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#autorot!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.autorot!/1","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flip - Whether the image was flipped or not. (`boolean()`)\n* angle - Angle image was rotated by. (`vips_angle`)","ref":"Vix.Vips.Operation.html#autorot!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.avg/1","doc":"Find image average","ref":"Vix.Vips.Operation.html#avg/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.avg/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#avg/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.avg!/1","doc":"Find image average","ref":"Vix.Vips.Operation.html#avg!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.avg!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#avg!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandbool/2","doc":"Boolean operation across image bands","ref":"Vix.Vips.Operation.html#bandbool/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandbool/2","doc":"* input - Input image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#bandbool/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandbool!/2","doc":"Boolean operation across image bands","ref":"Vix.Vips.Operation.html#bandbool!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandbool!/2","doc":"* input - Input image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#bandbool!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandfold/2","doc":"Fold up x axis into bands","ref":"Vix.Vips.Operation.html#bandfold/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandfold/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandfold/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandfold/2","doc":"* factor - Fold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandfold/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandfold!/2","doc":"Fold up x axis into bands","ref":"Vix.Vips.Operation.html#bandfold!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandfold!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandfold!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandfold!/2","doc":"* factor - Fold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandfold!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandjoin/1","doc":"Bandwise join a set of images","ref":"Vix.Vips.Operation.html#bandjoin/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandjoin/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandjoin!/1","doc":"Bandwise join a set of images","ref":"Vix.Vips.Operation.html#bandjoin!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin!/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandjoin!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandjoin_const/2","doc":"Append a constant band to an image","ref":"Vix.Vips.Operation.html#bandjoin_const/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin_const/2","doc":"* input - Input image\n  * c - Array of constants to add","ref":"Vix.Vips.Operation.html#bandjoin_const/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandjoin_const!/2","doc":"Append a constant band to an image","ref":"Vix.Vips.Operation.html#bandjoin_const!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin_const!/2","doc":"* input - Input image\n  * c - Array of constants to add","ref":"Vix.Vips.Operation.html#bandjoin_const!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandmean/1","doc":"Band-wise average","ref":"Vix.Vips.Operation.html#bandmean/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandmean/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#bandmean/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandmean!/1","doc":"Band-wise average","ref":"Vix.Vips.Operation.html#bandmean!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandmean!/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#bandmean!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandrank/2","doc":"Band-wise rank of a set of images","ref":"Vix.Vips.Operation.html#bandrank/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandrank/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandrank/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandrank/2","doc":"* index - Select this band element from sorted list. Default: `-1`","ref":"Vix.Vips.Operation.html#bandrank/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandrank!/2","doc":"Band-wise rank of a set of images","ref":"Vix.Vips.Operation.html#bandrank!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandrank!/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandrank!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandrank!/2","doc":"* index - Select this band element from sorted list. Default: `-1`","ref":"Vix.Vips.Operation.html#bandrank!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandunfold/2","doc":"Unfold image bands into x axis","ref":"Vix.Vips.Operation.html#bandunfold/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandunfold/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandunfold/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandunfold/2","doc":"* factor - Unfold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandunfold/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandunfold!/2","doc":"Unfold image bands into x axis","ref":"Vix.Vips.Operation.html#bandunfold!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandunfold!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandunfold!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandunfold!/2","doc":"* factor - Unfold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandunfold!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.black/3","doc":"Make a black image","ref":"Vix.Vips.Operation.html#black/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.black/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#black/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.black/3","doc":"* bands - Number of bands in image. Default: `1`","ref":"Vix.Vips.Operation.html#black/3-optional"},{"type":"function","title":"Vix.Vips.Operation.black!/3","doc":"Make a black image","ref":"Vix.Vips.Operation.html#black!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.black!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#black!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.black!/3","doc":"* bands - Number of bands in image. Default: `1`","ref":"Vix.Vips.Operation.html#black!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.boolean/3","doc":"Boolean operation on two images","ref":"Vix.Vips.Operation.html#boolean/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#boolean/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.boolean!/3","doc":"Boolean operation on two images","ref":"Vix.Vips.Operation.html#boolean!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#boolean!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.boolean_const/3","doc":"Boolean operations against a constant","ref":"Vix.Vips.Operation.html#boolean_const/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean_const/3","doc":"* input - Input image\n  * boolean - Boolean to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#boolean_const/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.boolean_const!/3","doc":"Boolean operations against a constant","ref":"Vix.Vips.Operation.html#boolean_const!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean_const!/3","doc":"* input - Input image\n  * boolean - Boolean to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#boolean_const!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.buildlut/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#buildlut/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.buildlut/1","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#buildlut/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.buildlut!/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#buildlut!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.buildlut!/1","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#buildlut!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.byteswap/1","doc":"Byteswap an image","ref":"Vix.Vips.Operation.html#byteswap/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.byteswap/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#byteswap/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.byteswap!/1","doc":"Byteswap an image","ref":"Vix.Vips.Operation.html#byteswap!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.byteswap!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#byteswap!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cache/2","doc":"Cache an image","ref":"Vix.Vips.Operation.html#cache/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cache/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cache/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cache/2","doc":"* tile-width - Tile width in pixels. Default: `128`\n* tile-height - Tile height in pixels. Default: `128`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`","ref":"Vix.Vips.Operation.html#cache/2-optional"},{"type":"function","title":"Vix.Vips.Operation.cache!/2","doc":"Cache an image","ref":"Vix.Vips.Operation.html#cache!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cache!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cache!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cache!/2","doc":"* tile-width - Tile width in pixels. Default: `128`\n* tile-height - Tile height in pixels. Default: `128`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`","ref":"Vix.Vips.Operation.html#cache!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.canny/2","doc":"Canny edge detector","ref":"Vix.Vips.Operation.html#canny/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.canny/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#canny/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.canny/2","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* sigma - Sigma of Gaussian. Default: `1.4`","ref":"Vix.Vips.Operation.html#canny/2-optional"},{"type":"function","title":"Vix.Vips.Operation.canny!/2","doc":"Canny edge detector","ref":"Vix.Vips.Operation.html#canny!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.canny!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#canny!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.canny!/2","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* sigma - Sigma of Gaussian. Default: `1.4`","ref":"Vix.Vips.Operation.html#canny!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.case/2","doc":"Use pixel values to pick cases from an array of images","ref":"Vix.Vips.Operation.html#case/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.case/2","doc":"* index - Index image\n  * cases - Array of case images","ref":"Vix.Vips.Operation.html#case/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.case!/2","doc":"Use pixel values to pick cases from an array of images","ref":"Vix.Vips.Operation.html#case!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.case!/2","doc":"* index - Index image\n  * cases - Array of case images","ref":"Vix.Vips.Operation.html#case!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.cast/3","doc":"Cast an image","ref":"Vix.Vips.Operation.html#cast/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cast/3","doc":"* input - Input image\n  * format - Format to cast to","ref":"Vix.Vips.Operation.html#cast/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cast/3","doc":"* shift - Shift integer values up and down. Default: `false`","ref":"Vix.Vips.Operation.html#cast/3-optional"},{"type":"function","title":"Vix.Vips.Operation.cast!/3","doc":"Cast an image","ref":"Vix.Vips.Operation.html#cast!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cast!/3","doc":"* input - Input image\n  * format - Format to cast to","ref":"Vix.Vips.Operation.html#cast!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cast!/3","doc":"* shift - Shift integer values up and down. Default: `false`","ref":"Vix.Vips.Operation.html#cast!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.cmc2lch/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#cmc2lch/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmc2lch/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmc2lch/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cmc2lch!/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#cmc2lch!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmc2lch!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmc2lch!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cmyk2xyz/1","doc":"Transform cmyk to xyz","ref":"Vix.Vips.Operation.html#cmyk2xyz/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmyk2xyz/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmyk2xyz/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cmyk2xyz!/1","doc":"Transform cmyk to xyz","ref":"Vix.Vips.Operation.html#cmyk2xyz!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmyk2xyz!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmyk2xyz!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.colourspace/3","doc":"Convert to a new colorspace","ref":"Vix.Vips.Operation.html#colourspace/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.colourspace/3","doc":"* input - Input image\n  * space - Destination color space","ref":"Vix.Vips.Operation.html#colourspace/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.colourspace/3","doc":"* source-space - Source color space. Default: `:VIPS_INTERPRETATION_sRGB`","ref":"Vix.Vips.Operation.html#colourspace/3-optional"},{"type":"function","title":"Vix.Vips.Operation.colourspace!/3","doc":"Convert to a new colorspace","ref":"Vix.Vips.Operation.html#colourspace!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.colourspace!/3","doc":"* input - Input image\n  * space - Destination color space","ref":"Vix.Vips.Operation.html#colourspace!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.colourspace!/3","doc":"* source-space - Source color space. Default: `:VIPS_INTERPRETATION_sRGB`","ref":"Vix.Vips.Operation.html#colourspace!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.compass/3","doc":"Convolve with rotating mask","ref":"Vix.Vips.Operation.html#compass/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.compass/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#compass/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.compass/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* combine - Combine convolution results like this. Default: `:VIPS_COMBINE_MAX`\n* angle - Rotate mask by this much between convolutions. Default: `:VIPS_ANGLE45_D90`\n* times - Rotate and convolve this many times. Default: `2`","ref":"Vix.Vips.Operation.html#compass/3-optional"},{"type":"function","title":"Vix.Vips.Operation.compass!/3","doc":"Convolve with rotating mask","ref":"Vix.Vips.Operation.html#compass!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.compass!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#compass!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.compass!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* combine - Combine convolution results like this. Default: `:VIPS_COMBINE_MAX`\n* angle - Rotate mask by this much between convolutions. Default: `:VIPS_ANGLE45_D90`\n* times - Rotate and convolve this many times. Default: `2`","ref":"Vix.Vips.Operation.html#compass!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.complex2/3","doc":"Complex binary operations on two images","ref":"Vix.Vips.Operation.html#complex2/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex2/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * cmplx - Binary complex operation to perform","ref":"Vix.Vips.Operation.html#complex2/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.complex2!/3","doc":"Complex binary operations on two images","ref":"Vix.Vips.Operation.html#complex2!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex2!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * cmplx - Binary complex operation to perform","ref":"Vix.Vips.Operation.html#complex2!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.complex/2","doc":"Perform a complex operation on an image","ref":"Vix.Vips.Operation.html#complex/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex/2","doc":"* input - Input image\n  * cmplx - Complex to perform","ref":"Vix.Vips.Operation.html#complex/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complex!/2","doc":"Perform a complex operation on an image","ref":"Vix.Vips.Operation.html#complex!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex!/2","doc":"* input - Input image\n  * cmplx - Complex to perform","ref":"Vix.Vips.Operation.html#complex!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexform/2","doc":"Form a complex image from two real images","ref":"Vix.Vips.Operation.html#complexform/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexform/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#complexform/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexform!/2","doc":"Form a complex image from two real images","ref":"Vix.Vips.Operation.html#complexform!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexform!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#complexform!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexget/2","doc":"Get a component from a complex image","ref":"Vix.Vips.Operation.html#complexget/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexget/2","doc":"* input - Input image\n  * get - Complex to perform","ref":"Vix.Vips.Operation.html#complexget/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexget!/2","doc":"Get a component from a complex image","ref":"Vix.Vips.Operation.html#complexget!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexget!/2","doc":"* input - Input image\n  * get - Complex to perform","ref":"Vix.Vips.Operation.html#complexget!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.composite2/4","doc":"Blend a pair of images with a blend mode","ref":"Vix.Vips.Operation.html#composite2/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite2/4","doc":"* base - Base image\n  * overlay - Overlay image\n  * mode - VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite2/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite2/4","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - y position of overlay. Default: `0`\n* x - x position of overlay. Default: `0`","ref":"Vix.Vips.Operation.html#composite2/4-optional"},{"type":"function","title":"Vix.Vips.Operation.composite2!/4","doc":"Blend a pair of images with a blend mode","ref":"Vix.Vips.Operation.html#composite2!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite2!/4","doc":"* base - Base image\n  * overlay - Overlay image\n  * mode - VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite2!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite2!/4","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - y position of overlay. Default: `0`\n* x - x position of overlay. Default: `0`","ref":"Vix.Vips.Operation.html#composite2!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.composite/3","doc":"Blend an array of images with an array of blend modes","ref":"Vix.Vips.Operation.html#composite/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite/3","doc":"* input - Array of input images\n  * mode - Array of VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite/3","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - Array of y coordinates to join at. Default: `nil`\n* x - Array of x coordinates to join at. Default: `nil`","ref":"Vix.Vips.Operation.html#composite/3-optional"},{"type":"function","title":"Vix.Vips.Operation.composite!/3","doc":"Blend an array of images with an array of blend modes","ref":"Vix.Vips.Operation.html#composite!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite!/3","doc":"* input - Array of input images\n  * mode - Array of VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite!/3","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - Array of y coordinates to join at. Default: `nil`\n* x - Array of x coordinates to join at. Default: `nil`","ref":"Vix.Vips.Operation.html#composite!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conv/3","doc":"Convolution operation","ref":"Vix.Vips.Operation.html#conv/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conv/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conv/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conv/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#conv/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conv!/3","doc":"Convolution operation","ref":"Vix.Vips.Operation.html#conv!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conv!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conv!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conv!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#conv!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conva/3","doc":"Approximate integer convolution","ref":"Vix.Vips.Operation.html#conva/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conva/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conva/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conva/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#conva/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conva!/3","doc":"Approximate integer convolution","ref":"Vix.Vips.Operation.html#conva!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conva!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conva!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conva!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#conva!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convasep/3","doc":"Approximate separable integer convolution","ref":"Vix.Vips.Operation.html#convasep/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convasep/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convasep/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convasep/3","doc":"* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#convasep/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convasep!/3","doc":"Approximate separable integer convolution","ref":"Vix.Vips.Operation.html#convasep!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convasep!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convasep!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convasep!/3","doc":"* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#convasep!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convf/2","doc":"Float convolution operation","ref":"Vix.Vips.Operation.html#convf/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convf/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convf/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convf!/2","doc":"Float convolution operation","ref":"Vix.Vips.Operation.html#convf!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convf!/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convf!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convi/2","doc":"Int convolution operation","ref":"Vix.Vips.Operation.html#convi/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convi/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convi/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convi!/2","doc":"Int convolution operation","ref":"Vix.Vips.Operation.html#convi!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convi!/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convi!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convsep/3","doc":"Separable convolution operation","ref":"Vix.Vips.Operation.html#convsep/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convsep/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convsep/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convsep/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#convsep/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convsep!/3","doc":"Separable convolution operation","ref":"Vix.Vips.Operation.html#convsep!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convsep!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convsep!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convsep!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#convsep!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.copy/2","doc":"Copy an image","ref":"Vix.Vips.Operation.html#copy/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.copy/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#copy/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.copy/2","doc":"* yoffset - Vertical offset of origin. Default: `0`\n* xoffset - Horizontal offset of origin. Default: `0`\n* yres - Vertical resolution in pixels/mm. Default: `0.0`\n* xres - Horizontal resolution in pixels/mm. Default: `0.0`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* coding - Pixel coding. Default: `:VIPS_CODING_NONE`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* bands - Number of bands in image. Default: `0`\n* height - Image height in pixels. Default: `0`\n* width - Image width in pixels. Default: `0`\n* swap - Swap bytes in image between little and big-endian. Default: `false`","ref":"Vix.Vips.Operation.html#copy/2-optional"},{"type":"function","title":"Vix.Vips.Operation.copy!/2","doc":"Copy an image","ref":"Vix.Vips.Operation.html#copy!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.copy!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#copy!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.copy!/2","doc":"* yoffset - Vertical offset of origin. Default: `0`\n* xoffset - Horizontal offset of origin. Default: `0`\n* yres - Vertical resolution in pixels/mm. Default: `0.0`\n* xres - Horizontal resolution in pixels/mm. Default: `0.0`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* coding - Pixel coding. Default: `:VIPS_CODING_NONE`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* bands - Number of bands in image. Default: `0`\n* height - Image height in pixels. Default: `0`\n* width - Image width in pixels. Default: `0`\n* swap - Swap bytes in image between little and big-endian. Default: `false`","ref":"Vix.Vips.Operation.html#copy!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.countlines/2","doc":"Count lines in an image","ref":"Vix.Vips.Operation.html#countlines/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.countlines/2","doc":"* input - Input image argument\n  * direction - Countlines left-right or up-down","ref":"Vix.Vips.Operation.html#countlines/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.countlines!/2","doc":"Count lines in an image","ref":"Vix.Vips.Operation.html#countlines!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.countlines!/2","doc":"* input - Input image argument\n  * direction - Countlines left-right or up-down","ref":"Vix.Vips.Operation.html#countlines!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.csvload/2","doc":"Load csv","ref":"Vix.Vips.Operation.html#csvload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#csvload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* separator - Set of separator characters. Default: `\";,\\t\"`\n* whitespace - Set of whitespace characters. Default: `\" \"`\n* lines - Read this many lines from the file. Default: `0`\n* skip - Skip this many lines at the start of the file. Default: `0`","ref":"Vix.Vips.Operation.html#csvload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.csvload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#csvload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.csvload!/2","doc":"Load csv","ref":"Vix.Vips.Operation.html#csvload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#csvload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* separator - Set of separator characters. Default: `\";,\\t\"`\n* whitespace - Set of whitespace characters. Default: `\" \"`\n* lines - Read this many lines from the file. Default: `0`\n* skip - Skip this many lines at the start of the file. Default: `0`","ref":"Vix.Vips.Operation.html#csvload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.csvload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#csvload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.csvsave/3","doc":"Save image to csv","ref":"Vix.Vips.Operation.html#csvsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#csvsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* separator - Separator characters. Default: `\"\\t\"`","ref":"Vix.Vips.Operation.html#csvsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.csvsave!/3","doc":"Save image to csv","ref":"Vix.Vips.Operation.html#csvsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#csvsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* separator - Separator characters. Default: `\"\\t\"`","ref":"Vix.Vips.Operation.html#csvsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.de00/2","doc":"Calculate de00","ref":"Vix.Vips.Operation.html#de00/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de00/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de00/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.de00!/2","doc":"Calculate de00","ref":"Vix.Vips.Operation.html#de00!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de00!/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de00!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.de76/2","doc":"Calculate de76","ref":"Vix.Vips.Operation.html#de76/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de76/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de76/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.de76!/2","doc":"Calculate de76","ref":"Vix.Vips.Operation.html#de76!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de76!/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de76!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.decmc/2","doc":"Calculate decmc","ref":"Vix.Vips.Operation.html#decmc/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.decmc/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#decmc/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.decmc!/2","doc":"Calculate decmc","ref":"Vix.Vips.Operation.html#decmc!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.decmc!/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#decmc!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.deviate/1","doc":"Find image standard deviation","ref":"Vix.Vips.Operation.html#deviate/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.deviate/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#deviate/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.deviate!/1","doc":"Find image standard deviation","ref":"Vix.Vips.Operation.html#deviate!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.deviate!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#deviate!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.divide/2","doc":"Divide two images","ref":"Vix.Vips.Operation.html#divide/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.divide/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#divide/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.divide!/2","doc":"Divide two images","ref":"Vix.Vips.Operation.html#divide!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.divide!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#divide!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.dzsave/3","doc":"Save image to deepzoom file","ref":"Vix.Vips.Operation.html#dzsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#dzsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.dzsave!/3","doc":"Save image to deepzoom file","ref":"Vix.Vips.Operation.html#dzsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#dzsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.dzsave_buffer/2","doc":"Save image to dz buffer","ref":"Vix.Vips.Operation.html#dzsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#dzsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.dzsave_buffer!/2","doc":"Save image to dz buffer","ref":"Vix.Vips.Operation.html#dzsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#dzsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.embed/6","doc":"Embed an image in a larger image","ref":"Vix.Vips.Operation.html#embed/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.embed/6","doc":"* input - Input image\n  * x - Left edge of input in output\n  * y - Top edge of input in output\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#embed/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.embed/6","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#embed/6-optional"},{"type":"function","title":"Vix.Vips.Operation.embed!/6","doc":"Embed an image in a larger image","ref":"Vix.Vips.Operation.html#embed!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.embed!/6","doc":"* input - Input image\n  * x - Left edge of input in output\n  * y - Top edge of input in output\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#embed!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.embed!/6","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#embed!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.extract_area/5","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#extract_area/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_area/5","doc":"* input - Input image\n  * left - Left edge of extract area\n  * top - Top edge of extract area\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#extract_area/5-arguments"},{"type":"function","title":"Vix.Vips.Operation.extract_area!/5","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#extract_area!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_area!/5","doc":"* input - Input image\n  * left - Left edge of extract area\n  * top - Top edge of extract area\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#extract_area!/5-arguments"},{"type":"function","title":"Vix.Vips.Operation.extract_band/3","doc":"Extract band from an image","ref":"Vix.Vips.Operation.html#extract_band/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_band/3","doc":"* input - Input image\n  * band - Band to extract","ref":"Vix.Vips.Operation.html#extract_band/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.extract_band/3","doc":"* n - Number of bands to extract. Default: `1`","ref":"Vix.Vips.Operation.html#extract_band/3-optional"},{"type":"function","title":"Vix.Vips.Operation.extract_band!/3","doc":"Extract band from an image","ref":"Vix.Vips.Operation.html#extract_band!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_band!/3","doc":"* input - Input image\n  * band - Band to extract","ref":"Vix.Vips.Operation.html#extract_band!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.extract_band!/3","doc":"* n - Number of bands to extract. Default: `1`","ref":"Vix.Vips.Operation.html#extract_band!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.eye/3","doc":"Make an image showing the eye's spatial response","ref":"Vix.Vips.Operation.html#eye/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.eye/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#eye/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.eye/3","doc":"* factor - Maximum spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#eye/3-optional"},{"type":"function","title":"Vix.Vips.Operation.eye!/3","doc":"Make an image showing the eye's spatial response","ref":"Vix.Vips.Operation.html#eye!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.eye!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#eye!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.eye!/3","doc":"* factor - Maximum spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#eye!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.falsecolour/1","doc":"False-color an image","ref":"Vix.Vips.Operation.html#falsecolour/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.falsecolour/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#falsecolour/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.falsecolour!/1","doc":"False-color an image","ref":"Vix.Vips.Operation.html#falsecolour!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.falsecolour!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#falsecolour!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.fastcor/2","doc":"Fast correlation","ref":"Vix.Vips.Operation.html#fastcor/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fastcor/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#fastcor/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.fastcor!/2","doc":"Fast correlation","ref":"Vix.Vips.Operation.html#fastcor!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fastcor!/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#fastcor!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.fill_nearest/1","doc":"Fill image zeros with nearest non-zero pixel","ref":"Vix.Vips.Operation.html#fill_nearest/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fill_nearest/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#fill_nearest/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.fill_nearest/1","doc":"Operation returns a tuple\n\n* out - Value of nearest non-zero pixel. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* distance - Distance to nearest non-zero pixel. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#fill_nearest/1-returns"},{"type":"function","title":"Vix.Vips.Operation.fill_nearest!/1","doc":"Fill image zeros with nearest non-zero pixel","ref":"Vix.Vips.Operation.html#fill_nearest!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fill_nearest!/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#fill_nearest!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.fill_nearest!/1","doc":"Operation returns a tuple\n\n* out - Value of nearest non-zero pixel. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* distance - Distance to nearest non-zero pixel. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#fill_nearest!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.find_trim/2","doc":"Search an image for non-edge areas","ref":"Vix.Vips.Operation.html#find_trim/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.find_trim/2","doc":"* input - Image to find_trim","ref":"Vix.Vips.Operation.html#find_trim/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.find_trim/2","doc":"* line-art - Enable line art mode. Default: `false`\n* background - Color for background pixels. Default: `nil`\n* threshold - Object threshold. Default: `10.0`","ref":"Vix.Vips.Operation.html#find_trim/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.find_trim/2","doc":"Operation returns a tuple\n\n* left - Left edge of image. (`integer()`)\n* top - Top edge of extract area. (`integer()`)\n* width - Width of extract area. (`integer()`)\n* height - Height of extract area. (`integer()`)","ref":"Vix.Vips.Operation.html#find_trim/2-returns"},{"type":"function","title":"Vix.Vips.Operation.find_trim!/2","doc":"Search an image for non-edge areas","ref":"Vix.Vips.Operation.html#find_trim!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.find_trim!/2","doc":"* input - Image to find_trim","ref":"Vix.Vips.Operation.html#find_trim!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.find_trim!/2","doc":"* line-art - Enable line art mode. Default: `false`\n* background - Color for background pixels. Default: `nil`\n* threshold - Object threshold. Default: `10.0`","ref":"Vix.Vips.Operation.html#find_trim!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.find_trim!/2","doc":"Operation returns a tuple\n\n* left - Left edge of image. (`integer()`)\n* top - Top edge of extract area. (`integer()`)\n* width - Width of extract area. (`integer()`)\n* height - Height of extract area. (`integer()`)","ref":"Vix.Vips.Operation.html#find_trim!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.flatten/2","doc":"Flatten alpha out of an image","ref":"Vix.Vips.Operation.html#flatten/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flatten/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#flatten/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.flatten/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`\n* background - Background value. Default: `nil`","ref":"Vix.Vips.Operation.html#flatten/2-optional"},{"type":"function","title":"Vix.Vips.Operation.flatten!/2","doc":"Flatten alpha out of an image","ref":"Vix.Vips.Operation.html#flatten!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flatten!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#flatten!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.flatten!/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`\n* background - Background value. Default: `nil`","ref":"Vix.Vips.Operation.html#flatten!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.flip/2","doc":"Flip an image","ref":"Vix.Vips.Operation.html#flip/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flip/2","doc":"* input - Input image\n  * direction - Direction to flip image","ref":"Vix.Vips.Operation.html#flip/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.flip!/2","doc":"Flip an image","ref":"Vix.Vips.Operation.html#flip!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flip!/2","doc":"* input - Input image\n  * direction - Direction to flip image","ref":"Vix.Vips.Operation.html#flip!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.float2rad/1","doc":"Transform float rgb to radiance coding","ref":"Vix.Vips.Operation.html#float2rad/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.float2rad/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#float2rad/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.float2rad!/1","doc":"Transform float rgb to radiance coding","ref":"Vix.Vips.Operation.html#float2rad!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.float2rad!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#float2rad!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.fractsurf/3","doc":"Make a fractal surface","ref":"Vix.Vips.Operation.html#fractsurf/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fractsurf/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#fractsurf/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.fractsurf!/3","doc":"Make a fractal surface","ref":"Vix.Vips.Operation.html#fractsurf!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fractsurf!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#fractsurf!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.freqmult/2","doc":"Frequency-domain filtering","ref":"Vix.Vips.Operation.html#freqmult/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.freqmult/2","doc":"* input - Input image\n  * mask - Input mask image","ref":"Vix.Vips.Operation.html#freqmult/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.freqmult!/2","doc":"Frequency-domain filtering","ref":"Vix.Vips.Operation.html#freqmult!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.freqmult!/2","doc":"* input - Input image\n  * mask - Input mask image","ref":"Vix.Vips.Operation.html#freqmult!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.gamma/2","doc":"Gamma an image","ref":"Vix.Vips.Operation.html#gamma/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gamma/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#gamma/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gamma/2","doc":"* exponent - Gamma factor. Default: `2.4`","ref":"Vix.Vips.Operation.html#gamma/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gamma!/2","doc":"Gamma an image","ref":"Vix.Vips.Operation.html#gamma!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gamma!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#gamma!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gamma!/2","doc":"* exponent - Gamma factor. Default: `2.4`","ref":"Vix.Vips.Operation.html#gamma!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussblur/3","doc":"Gaussian blur","ref":"Vix.Vips.Operation.html#gaussblur/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussblur/3","doc":"* input - Input image\n  * sigma - Sigma of Gaussian","ref":"Vix.Vips.Operation.html#gaussblur/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussblur/3","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* min-ampl - Minimum amplitude of Gaussian. Default: `0.2`","ref":"Vix.Vips.Operation.html#gaussblur/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussblur!/3","doc":"Gaussian blur","ref":"Vix.Vips.Operation.html#gaussblur!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussblur!/3","doc":"* input - Input image\n  * sigma - Sigma of Gaussian","ref":"Vix.Vips.Operation.html#gaussblur!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussblur!/3","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* min-ampl - Minimum amplitude of Gaussian. Default: `0.2`","ref":"Vix.Vips.Operation.html#gaussblur!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussmat/3","doc":"Make a gaussian image","ref":"Vix.Vips.Operation.html#gaussmat/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussmat/3","doc":"* sigma - Sigma of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#gaussmat/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussmat/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#gaussmat/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussmat!/3","doc":"Make a gaussian image","ref":"Vix.Vips.Operation.html#gaussmat!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussmat!/3","doc":"* sigma - Sigma of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#gaussmat!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussmat!/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#gaussmat!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussnoise/3","doc":"Make a gaussnoise image","ref":"Vix.Vips.Operation.html#gaussnoise/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussnoise/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gaussnoise/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussnoise/3","doc":"* seed - Random number seed. Default: `0`\n* mean - Mean of pixels in generated image. Default: `128.0`\n* sigma - Standard deviation of pixels in generated image. Default: `30.0`","ref":"Vix.Vips.Operation.html#gaussnoise/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussnoise!/3","doc":"Make a gaussnoise image","ref":"Vix.Vips.Operation.html#gaussnoise!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussnoise!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gaussnoise!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussnoise!/3","doc":"* seed - Random number seed. Default: `0`\n* mean - Mean of pixels in generated image. Default: `128.0`\n* sigma - Standard deviation of pixels in generated image. Default: `30.0`","ref":"Vix.Vips.Operation.html#gaussnoise!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.getpoint/3","doc":"Read a point from an image","ref":"Vix.Vips.Operation.html#getpoint/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.getpoint/3","doc":"* input - Input image\n  * x - Point to read\n  * y - Point to read","ref":"Vix.Vips.Operation.html#getpoint/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.getpoint!/3","doc":"Read a point from an image","ref":"Vix.Vips.Operation.html#getpoint!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.getpoint!/3","doc":"* input - Input image\n  * x - Point to read\n  * y - Point to read","ref":"Vix.Vips.Operation.html#getpoint!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.gifload/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#gifload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifload!/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#gifload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifload_buffer/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#gifload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifload_buffer!/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#gifload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifsave/3","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#gifsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gifsave!/3","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#gifsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gifsave_buffer/2","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#gifsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gifsave_buffer!/2","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#gifsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.globalbalance/2","doc":"Global balance an image mosaic","ref":"Vix.Vips.Operation.html#globalbalance/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.globalbalance/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#globalbalance/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.globalbalance/2","doc":"* int-output - Integer output. Default: `false`\n* gamma - Image gamma. Default: `1.6`","ref":"Vix.Vips.Operation.html#globalbalance/2-optional"},{"type":"function","title":"Vix.Vips.Operation.globalbalance!/2","doc":"Global balance an image mosaic","ref":"Vix.Vips.Operation.html#globalbalance!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.globalbalance!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#globalbalance!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.globalbalance!/2","doc":"* int-output - Integer output. Default: `false`\n* gamma - Image gamma. Default: `1.6`","ref":"Vix.Vips.Operation.html#globalbalance!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gravity/5","doc":"Place an image within a larger image with a certain gravity","ref":"Vix.Vips.Operation.html#gravity/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gravity/5","doc":"* input - Input image\n  * direction - Direction to place image within width/height\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gravity/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gravity/5","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#gravity/5-optional"},{"type":"function","title":"Vix.Vips.Operation.gravity!/5","doc":"Place an image within a larger image with a certain gravity","ref":"Vix.Vips.Operation.html#gravity!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gravity!/5","doc":"* input - Input image\n  * direction - Direction to place image within width/height\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gravity!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gravity!/5","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#gravity!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.grey/3","doc":"Make a grey ramp image","ref":"Vix.Vips.Operation.html#grey/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grey/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#grey/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.grey/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#grey/3-optional"},{"type":"function","title":"Vix.Vips.Operation.grey!/3","doc":"Make a grey ramp image","ref":"Vix.Vips.Operation.html#grey!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grey!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#grey!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.grey!/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#grey!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.grid/4","doc":"Grid an image","ref":"Vix.Vips.Operation.html#grid/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grid/4","doc":"* input - Input image\n  * tile-height - Chop into tiles this high\n  * across - Number of tiles across\n  * down - Number of tiles down","ref":"Vix.Vips.Operation.html#grid/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.grid!/4","doc":"Grid an image","ref":"Vix.Vips.Operation.html#grid!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grid!/4","doc":"* input - Input image\n  * tile-height - Chop into tiles this high\n  * across - Number of tiles across\n  * down - Number of tiles down","ref":"Vix.Vips.Operation.html#grid!/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.heifload/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#heifload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifload!/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#heifload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifload_buffer/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#heifload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifload_buffer!/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#heifload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifsave/3","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#heifsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.heifsave!/3","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#heifsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.heifsave_buffer/2","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#heifsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.heifsave_buffer!/2","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#heifsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_cum/1","doc":"Form cumulative histogram","ref":"Vix.Vips.Operation.html#hist_cum/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_cum/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_cum/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_cum!/1","doc":"Form cumulative histogram","ref":"Vix.Vips.Operation.html#hist_cum!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_cum!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_cum!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_entropy/1","doc":"Estimate image entropy","ref":"Vix.Vips.Operation.html#hist_entropy/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_entropy/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_entropy/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_entropy!/1","doc":"Estimate image entropy","ref":"Vix.Vips.Operation.html#hist_entropy!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_entropy!/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_entropy!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_equal/2","doc":"Histogram equalisation","ref":"Vix.Vips.Operation.html#hist_equal/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_equal/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_equal/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_equal/2","doc":"* band - Equalise with this band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_equal/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_equal!/2","doc":"Histogram equalisation","ref":"Vix.Vips.Operation.html#hist_equal!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_equal!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_equal!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_equal!/2","doc":"* band - Equalise with this band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_equal!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find/2","doc":"Find image histogram","ref":"Vix.Vips.Operation.html#hist_find/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find/2","doc":"* band - Find histogram of band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_find/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find!/2","doc":"Find image histogram","ref":"Vix.Vips.Operation.html#hist_find!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find!/2","doc":"* band - Find histogram of band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_find!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_indexed/3","doc":"Find indexed image histogram","ref":"Vix.Vips.Operation.html#hist_find_indexed/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_indexed/3","doc":"* input - Input image\n  * index - Index image","ref":"Vix.Vips.Operation.html#hist_find_indexed/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_indexed/3","doc":"* combine - Combine bins like this. Default: `:VIPS_COMBINE_SUM`","ref":"Vix.Vips.Operation.html#hist_find_indexed/3-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_indexed!/3","doc":"Find indexed image histogram","ref":"Vix.Vips.Operation.html#hist_find_indexed!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_indexed!/3","doc":"* input - Input image\n  * index - Index image","ref":"Vix.Vips.Operation.html#hist_find_indexed!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_indexed!/3","doc":"* combine - Combine bins like this. Default: `:VIPS_COMBINE_SUM`","ref":"Vix.Vips.Operation.html#hist_find_indexed!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_ndim/2","doc":"Find n-dimensional image histogram","ref":"Vix.Vips.Operation.html#hist_find_ndim/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_ndim/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find_ndim/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_ndim/2","doc":"* bins - Number of bins in each dimension. Default: `10`","ref":"Vix.Vips.Operation.html#hist_find_ndim/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_ndim!/2","doc":"Find n-dimensional image histogram","ref":"Vix.Vips.Operation.html#hist_find_ndim!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_ndim!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find_ndim!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_ndim!/2","doc":"* bins - Number of bins in each dimension. Default: `10`","ref":"Vix.Vips.Operation.html#hist_find_ndim!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_ismonotonic/1","doc":"Test for monotonicity","ref":"Vix.Vips.Operation.html#hist_ismonotonic/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_ismonotonic/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_ismonotonic/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_ismonotonic!/1","doc":"Test for monotonicity","ref":"Vix.Vips.Operation.html#hist_ismonotonic!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_ismonotonic!/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_ismonotonic!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_local/4","doc":"Local histogram equalisation","ref":"Vix.Vips.Operation.html#hist_local/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_local/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#hist_local/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_local/4","doc":"* max-slope - Maximum slope (CLAHE). Default: `0`","ref":"Vix.Vips.Operation.html#hist_local/4-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_local!/4","doc":"Local histogram equalisation","ref":"Vix.Vips.Operation.html#hist_local!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_local!/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#hist_local!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_local!/4","doc":"* max-slope - Maximum slope (CLAHE). Default: `0`","ref":"Vix.Vips.Operation.html#hist_local!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_match/2","doc":"Match two histograms","ref":"Vix.Vips.Operation.html#hist_match/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_match/2","doc":"* input - Input histogram\n  * ref - Reference histogram","ref":"Vix.Vips.Operation.html#hist_match/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_match!/2","doc":"Match two histograms","ref":"Vix.Vips.Operation.html#hist_match!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_match!/2","doc":"* input - Input histogram\n  * ref - Reference histogram","ref":"Vix.Vips.Operation.html#hist_match!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_norm/1","doc":"Normalise histogram","ref":"Vix.Vips.Operation.html#hist_norm/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_norm/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_norm/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_norm!/1","doc":"Normalise histogram","ref":"Vix.Vips.Operation.html#hist_norm!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_norm!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_norm!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_plot/1","doc":"Plot histogram","ref":"Vix.Vips.Operation.html#hist_plot/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_plot/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_plot/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_plot!/1","doc":"Plot histogram","ref":"Vix.Vips.Operation.html#hist_plot!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_plot!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_plot!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hough_circle/2","doc":"Find hough circle transform","ref":"Vix.Vips.Operation.html#hough_circle/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_circle/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_circle/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_circle/2","doc":"* max-radius - Largest radius to search for. Default: `20`\n* min-radius - Smallest radius to search for. Default: `10`\n* scale - Scale down dimensions by this factor. Default: `3`","ref":"Vix.Vips.Operation.html#hough_circle/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hough_circle!/2","doc":"Find hough circle transform","ref":"Vix.Vips.Operation.html#hough_circle!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_circle!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_circle!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_circle!/2","doc":"* max-radius - Largest radius to search for. Default: `20`\n* min-radius - Smallest radius to search for. Default: `10`\n* scale - Scale down dimensions by this factor. Default: `3`","ref":"Vix.Vips.Operation.html#hough_circle!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hough_line/2","doc":"Find hough line transform","ref":"Vix.Vips.Operation.html#hough_line/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_line/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_line/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_line/2","doc":"* height - Vertical size of parameter space. Default: `256`\n* width - Horizontal size of parameter space. Default: `256`","ref":"Vix.Vips.Operation.html#hough_line/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hough_line!/2","doc":"Find hough line transform","ref":"Vix.Vips.Operation.html#hough_line!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_line!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_line!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_line!/2","doc":"* height - Vertical size of parameter space. Default: `256`\n* width - Horizontal size of parameter space. Default: `256`","ref":"Vix.Vips.Operation.html#hough_line!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hsv2srgb/1","doc":"Transform hsv to srgb","ref":"Vix.Vips.Operation.html#hsv2srgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hsv2srgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hsv2srgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hsv2srgb!/1","doc":"Transform hsv to srgb","ref":"Vix.Vips.Operation.html#hsv2srgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hsv2srgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hsv2srgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.icc_export/2","doc":"Output to device with icc profile","ref":"Vix.Vips.Operation.html#icc_export/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_export/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_export/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_export/2","doc":"* depth - Output device space depth in bits. Default: `8`\n* output-profile - Filename to load output profile from. Default: `nil`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_export/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_export!/2","doc":"Output to device with icc profile","ref":"Vix.Vips.Operation.html#icc_export!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_export!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_export!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_export!/2","doc":"* depth - Output device space depth in bits. Default: `8`\n* output-profile - Filename to load output profile from. Default: `nil`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_export!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_import/2","doc":"Import from device with icc profile","ref":"Vix.Vips.Operation.html#icc_import/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_import/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_import/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_import/2","doc":"* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_import/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_import!/2","doc":"Import from device with icc profile","ref":"Vix.Vips.Operation.html#icc_import!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_import!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_import!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_import!/2","doc":"* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_import!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_transform/3","doc":"Transform between devices with icc profiles","ref":"Vix.Vips.Operation.html#icc_transform/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_transform/3","doc":"* input - Input image\n  * output-profile - Filename to load output profile from","ref":"Vix.Vips.Operation.html#icc_transform/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_transform/3","doc":"* depth - Output device space depth in bits. Default: `8`\n* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_transform/3-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_transform!/3","doc":"Transform between devices with icc profiles","ref":"Vix.Vips.Operation.html#icc_transform!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_transform!/3","doc":"* input - Input image\n  * output-profile - Filename to load output profile from","ref":"Vix.Vips.Operation.html#icc_transform!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_transform!/3","doc":"* depth - Output device space depth in bits. Default: `8`\n* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_transform!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.identity/1","doc":"Make a 1d image where pixel values are indexes","ref":"Vix.Vips.Operation.html#identity/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.identity/1","doc":"","ref":"Vix.Vips.Operation.html#identity/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.identity/1","doc":"* size - Size of 16-bit LUT. Default: `65536`\n* ushort - Create a 16-bit LUT. Default: `false`\n* bands - Number of bands in LUT. Default: `1`","ref":"Vix.Vips.Operation.html#identity/1-optional"},{"type":"function","title":"Vix.Vips.Operation.identity!/1","doc":"Make a 1d image where pixel values are indexes","ref":"Vix.Vips.Operation.html#identity!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.identity!/1","doc":"","ref":"Vix.Vips.Operation.html#identity!/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.identity!/1","doc":"* size - Size of 16-bit LUT. Default: `65536`\n* ushort - Create a 16-bit LUT. Default: `false`\n* bands - Number of bands in LUT. Default: `1`","ref":"Vix.Vips.Operation.html#identity!/1-optional"},{"type":"function","title":"Vix.Vips.Operation.ifthenelse/4","doc":"Ifthenelse an image","ref":"Vix.Vips.Operation.html#ifthenelse/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.ifthenelse/4","doc":"* cond - Condition input image\n  * in1 - Source for TRUE pixels\n  * in2 - Source for FALSE pixels","ref":"Vix.Vips.Operation.html#ifthenelse/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.ifthenelse/4","doc":"* blend - Blend smoothly between then and else parts. Default: `false`","ref":"Vix.Vips.Operation.html#ifthenelse/4-optional"},{"type":"function","title":"Vix.Vips.Operation.ifthenelse!/4","doc":"Ifthenelse an image","ref":"Vix.Vips.Operation.html#ifthenelse!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.ifthenelse!/4","doc":"* cond - Condition input image\n  * in1 - Source for TRUE pixels\n  * in2 - Source for FALSE pixels","ref":"Vix.Vips.Operation.html#ifthenelse!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.ifthenelse!/4","doc":"* blend - Blend smoothly between then and else parts. Default: `false`","ref":"Vix.Vips.Operation.html#ifthenelse!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.insert/5","doc":"Insert image @sub into @main at @x, @y","ref":"Vix.Vips.Operation.html#insert/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.insert/5","doc":"* main - Main input image\n  * sub - Sub-image to insert into main image\n  * x - Left edge of sub in main\n  * y - Top edge of sub in main","ref":"Vix.Vips.Operation.html#insert/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.insert/5","doc":"* background - Color for new pixels. Default: `nil`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#insert/5-optional"},{"type":"function","title":"Vix.Vips.Operation.insert!/5","doc":"Insert image @sub into @main at @x, @y","ref":"Vix.Vips.Operation.html#insert!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.insert!/5","doc":"* main - Main input image\n  * sub - Sub-image to insert into main image\n  * x - Left edge of sub in main\n  * y - Top edge of sub in main","ref":"Vix.Vips.Operation.html#insert!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.insert!/5","doc":"* background - Color for new pixels. Default: `nil`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#insert!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.invert/1","doc":"Invert an image","ref":"Vix.Vips.Operation.html#invert/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invert/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#invert/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.invert!/1","doc":"Invert an image","ref":"Vix.Vips.Operation.html#invert!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invert!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#invert!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.invertlut/2","doc":"Build an inverted look-up table","ref":"Vix.Vips.Operation.html#invertlut/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invertlut/2","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#invertlut/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.invertlut/2","doc":"* size - LUT size to generate. Default: `256`","ref":"Vix.Vips.Operation.html#invertlut/2-optional"},{"type":"function","title":"Vix.Vips.Operation.invertlut!/2","doc":"Build an inverted look-up table","ref":"Vix.Vips.Operation.html#invertlut!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invertlut!/2","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#invertlut!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.invertlut!/2","doc":"* size - LUT size to generate. Default: `256`","ref":"Vix.Vips.Operation.html#invertlut!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.join/4","doc":"Join a pair of images","ref":"Vix.Vips.Operation.html#join/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.join/4","doc":"* in1 - First input image\n  * in2 - Second input image\n  * direction - Join left-right or up-down","ref":"Vix.Vips.Operation.html#join/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.join/4","doc":"* align - Align on the low, centre or high coordinate edge. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#join/4-optional"},{"type":"function","title":"Vix.Vips.Operation.join!/4","doc":"Join a pair of images","ref":"Vix.Vips.Operation.html#join!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.join!/4","doc":"* in1 - First input image\n  * in2 - Second input image\n  * direction - Join left-right or up-down","ref":"Vix.Vips.Operation.html#join!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.join!/4","doc":"* align - Align on the low, centre or high coordinate edge. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#join!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegload/2","doc":"Load jpeg from file","ref":"Vix.Vips.Operation.html#jpegload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#jpegload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegload!/2","doc":"Load jpeg from file","ref":"Vix.Vips.Operation.html#jpegload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#jpegload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegload_buffer/2","doc":"Load jpeg from buffer","ref":"Vix.Vips.Operation.html#jpegload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#jpegload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegload_buffer!/2","doc":"Load jpeg from buffer","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegsave/3","doc":"Save image to jpeg file","ref":"Vix.Vips.Operation.html#jpegsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#jpegsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave!/3","doc":"Save image to jpeg file","ref":"Vix.Vips.Operation.html#jpegsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#jpegsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_buffer/2","doc":"Save image to jpeg buffer","ref":"Vix.Vips.Operation.html#jpegsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_buffer!/2","doc":"Save image to jpeg buffer","ref":"Vix.Vips.Operation.html#jpegsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_mime/2","doc":"Save image to jpeg mime","ref":"Vix.Vips.Operation.html#jpegsave_mime/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_mime/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_mime/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_mime/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_mime/2-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_mime!/2","doc":"Save image to jpeg mime","ref":"Vix.Vips.Operation.html#jpegsave_mime!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_mime!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_mime!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_mime!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_mime!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.lab2labq/1","doc":"Transform float lab to labq coding","ref":"Vix.Vips.Operation.html#lab2labq/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labq/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labq/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2labq!/1","doc":"Transform float lab to labq coding","ref":"Vix.Vips.Operation.html#lab2labq!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labq!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labq!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2labs/1","doc":"Transform float lab to signed short","ref":"Vix.Vips.Operation.html#lab2labs/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labs/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labs/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2labs!/1","doc":"Transform float lab to signed short","ref":"Vix.Vips.Operation.html#lab2labs!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labs!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labs!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2lch/1","doc":"Transform lab to lch","ref":"Vix.Vips.Operation.html#lab2lch/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2lch/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2lch/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2lch!/1","doc":"Transform lab to lch","ref":"Vix.Vips.Operation.html#lab2lch!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2lch!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2lch!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2xyz/2","doc":"Transform cielab to xyz","ref":"Vix.Vips.Operation.html#lab2xyz/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2xyz/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2xyz/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.lab2xyz/2","doc":"* temp - Color temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#lab2xyz/2-optional"},{"type":"function","title":"Vix.Vips.Operation.lab2xyz!/2","doc":"Transform cielab to xyz","ref":"Vix.Vips.Operation.html#lab2xyz!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2xyz!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2xyz!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.lab2xyz!/2","doc":"* temp - Color temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#lab2xyz!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.labelregions/1","doc":"Label regions in an image","ref":"Vix.Vips.Operation.html#labelregions/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labelregions/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#labelregions/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.labelregions/1","doc":"Operation returns a tuple\n\n* mask - Mask of region labels. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* segments - Number of discrete contiguous regions. (`integer()`)","ref":"Vix.Vips.Operation.html#labelregions/1-returns"},{"type":"function","title":"Vix.Vips.Operation.labelregions!/1","doc":"Label regions in an image","ref":"Vix.Vips.Operation.html#labelregions!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labelregions!/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#labelregions!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.labelregions!/1","doc":"Operation returns a tuple\n\n* mask - Mask of region labels. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* segments - Number of discrete contiguous regions. (`integer()`)","ref":"Vix.Vips.Operation.html#labelregions!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.labq2lab/1","doc":"Unpack a labq image to float lab","ref":"Vix.Vips.Operation.html#labq2lab/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2lab/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2lab/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2lab!/1","doc":"Unpack a labq image to float lab","ref":"Vix.Vips.Operation.html#labq2lab!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2lab!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2lab!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2labs/1","doc":"Unpack a labq image to short lab","ref":"Vix.Vips.Operation.html#labq2labs/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2labs/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2labs/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2labs!/1","doc":"Unpack a labq image to short lab","ref":"Vix.Vips.Operation.html#labq2labs!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2labs!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2labs!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2srgb/1","doc":"Convert a labq image to srgb","ref":"Vix.Vips.Operation.html#labq2srgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2srgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2srgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2srgb!/1","doc":"Convert a labq image to srgb","ref":"Vix.Vips.Operation.html#labq2srgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2srgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2srgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2lab/1","doc":"Transform signed short lab to float","ref":"Vix.Vips.Operation.html#labs2lab/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2lab/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2lab/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2lab!/1","doc":"Transform signed short lab to float","ref":"Vix.Vips.Operation.html#labs2lab!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2lab!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2lab!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2labq/1","doc":"Transform short lab to labq coding","ref":"Vix.Vips.Operation.html#labs2labq/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2labq/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2labq/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2labq!/1","doc":"Transform short lab to labq coding","ref":"Vix.Vips.Operation.html#labs2labq!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2labq!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2labq!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2cmc/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#lch2cmc/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2cmc/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2cmc/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2cmc!/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#lch2cmc!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2cmc!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2cmc!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2lab/1","doc":"Transform lch to lab","ref":"Vix.Vips.Operation.html#lch2lab/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2lab/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2lab/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2lab!/1","doc":"Transform lch to lab","ref":"Vix.Vips.Operation.html#lch2lab!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2lab!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2lab!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.linear/4","doc":"Calculate (a * in + b)","ref":"Vix.Vips.Operation.html#linear/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linear/4","doc":"* input - Input image\n  * a - Multiply by this\n  * b - Add this","ref":"Vix.Vips.Operation.html#linear/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linear/4","doc":"* uchar - Output should be uchar. Default: `false`","ref":"Vix.Vips.Operation.html#linear/4-optional"},{"type":"function","title":"Vix.Vips.Operation.linear!/4","doc":"Calculate (a * in + b)","ref":"Vix.Vips.Operation.html#linear!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linear!/4","doc":"* input - Input image\n  * a - Multiply by this\n  * b - Add this","ref":"Vix.Vips.Operation.html#linear!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linear!/4","doc":"* uchar - Output should be uchar. Default: `false`","ref":"Vix.Vips.Operation.html#linear!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.linecache/2","doc":"Cache an image as a set of lines","ref":"Vix.Vips.Operation.html#linecache/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linecache/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#linecache/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linecache/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* tile-height - Tile height in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#linecache/2-optional"},{"type":"function","title":"Vix.Vips.Operation.linecache!/2","doc":"Cache an image as a set of lines","ref":"Vix.Vips.Operation.html#linecache!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linecache!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#linecache!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linecache!/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* tile-height - Tile height in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#linecache!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.logmat/3","doc":"Make a laplacian of gaussian image","ref":"Vix.Vips.Operation.html#logmat/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.logmat/3","doc":"* sigma - Radius of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#logmat/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.logmat/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#logmat/3-optional"},{"type":"function","title":"Vix.Vips.Operation.logmat!/3","doc":"Make a laplacian of gaussian image","ref":"Vix.Vips.Operation.html#logmat!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.logmat!/3","doc":"* sigma - Radius of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#logmat!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.logmat!/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#logmat!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.mapim/3","doc":"Resample with a map image","ref":"Vix.Vips.Operation.html#mapim/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mapim/3","doc":"* input - Input image argument\n  * index - Index pixels with this","ref":"Vix.Vips.Operation.html#mapim/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mapim/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#mapim/3-optional"},{"type":"function","title":"Vix.Vips.Operation.mapim!/3","doc":"Resample with a map image","ref":"Vix.Vips.Operation.html#mapim!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mapim!/3","doc":"* input - Input image argument\n  * index - Index pixels with this","ref":"Vix.Vips.Operation.html#mapim!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mapim!/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#mapim!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.maplut/3","doc":"Map an image though a lut","ref":"Vix.Vips.Operation.html#maplut/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.maplut/3","doc":"* input - Input image\n  * lut - Look-up table image","ref":"Vix.Vips.Operation.html#maplut/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.maplut/3","doc":"* band - Apply one-band lut to this band of in. Default: `-1`","ref":"Vix.Vips.Operation.html#maplut/3-optional"},{"type":"function","title":"Vix.Vips.Operation.maplut!/3","doc":"Map an image though a lut","ref":"Vix.Vips.Operation.html#maplut!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.maplut!/3","doc":"* input - Input image\n  * lut - Look-up table image","ref":"Vix.Vips.Operation.html#maplut!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.maplut!/3","doc":"* band - Apply one-band lut to this band of in. Default: `-1`","ref":"Vix.Vips.Operation.html#maplut!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth/6","doc":"Make a butterworth filter","ref":"Vix.Vips.Operation.html#mask_butterworth/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth!/6","doc":"Make a butterworth filter","ref":"Vix.Vips.Operation.html#mask_butterworth!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth!/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth!/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_band/8","doc":"Make a butterworth_band filter","ref":"Vix.Vips.Operation.html#mask_butterworth_band/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_band/8","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth_band/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_band/8","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_band/8-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_band!/8","doc":"Make a butterworth_band filter","ref":"Vix.Vips.Operation.html#mask_butterworth_band!/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_band!/8","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth_band!/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_band!/8","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_band!/8-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_ring/7","doc":"Make a butterworth ring filter","ref":"Vix.Vips.Operation.html#mask_butterworth_ring/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_ring/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_butterworth_ring/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_ring/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_ring/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_ring!/7","doc":"Make a butterworth ring filter","ref":"Vix.Vips.Operation.html#mask_butterworth_ring!/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_ring!/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_butterworth_ring!/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_ring!/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_ring!/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_fractal/4","doc":"Make fractal filter","ref":"Vix.Vips.Operation.html#mask_fractal/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_fractal/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#mask_fractal/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_fractal/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_fractal/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_fractal!/4","doc":"Make fractal filter","ref":"Vix.Vips.Operation.html#mask_fractal!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_fractal!/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#mask_fractal!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_fractal!/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_fractal!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian/5","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian/5-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian!/5","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian!/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian!/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_band/7","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian_band/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_band/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian_band/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_band/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_band/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_band!/7","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian_band!/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_band!/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian_band!/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_band!/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_band!/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_ring/6","doc":"Make a gaussian ring filter","ref":"Vix.Vips.Operation.html#mask_gaussian_ring/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_ring/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_gaussian_ring/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_ring/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_ring/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_ring!/6","doc":"Make a gaussian ring filter","ref":"Vix.Vips.Operation.html#mask_gaussian_ring!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_ring!/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_gaussian_ring!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_ring!/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_ring!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal/4","doc":"Make an ideal filter","ref":"Vix.Vips.Operation.html#mask_ideal/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff","ref":"Vix.Vips.Operation.html#mask_ideal/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal!/4","doc":"Make an ideal filter","ref":"Vix.Vips.Operation.html#mask_ideal!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal!/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff","ref":"Vix.Vips.Operation.html#mask_ideal!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal!/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_band/6","doc":"Make an ideal band filter","ref":"Vix.Vips.Operation.html#mask_ideal_band/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_band/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle","ref":"Vix.Vips.Operation.html#mask_ideal_band/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_band/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_band/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_band!/6","doc":"Make an ideal band filter","ref":"Vix.Vips.Operation.html#mask_ideal_band!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_band!/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle","ref":"Vix.Vips.Operation.html#mask_ideal_band!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_band!/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_band!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_ring/5","doc":"Make an ideal ring filter","ref":"Vix.Vips.Operation.html#mask_ideal_ring/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_ring/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_ideal_ring/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_ring/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_ring/5-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_ring!/5","doc":"Make an ideal ring filter","ref":"Vix.Vips.Operation.html#mask_ideal_ring!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_ring!/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_ideal_ring!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_ring!/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_ring!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.match/11","doc":"First-order match of two images","ref":"Vix.Vips.Operation.html#match/11"},{"type":"function","title":"Arguments - Vix.Vips.Operation.match/11","doc":"* ref - Reference image\n  * sec - Secondary image\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#match/11-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.match/11","doc":"* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `1`\n* hwindow - Half window size. Default: `1`","ref":"Vix.Vips.Operation.html#match/11-optional"},{"type":"function","title":"Vix.Vips.Operation.match!/11","doc":"First-order match of two images","ref":"Vix.Vips.Operation.html#match!/11"},{"type":"function","title":"Arguments - Vix.Vips.Operation.match!/11","doc":"* ref - Reference image\n  * sec - Secondary image\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#match!/11-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.match!/11","doc":"* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `1`\n* hwindow - Half window size. Default: `1`","ref":"Vix.Vips.Operation.html#match!/11-optional"},{"type":"function","title":"Vix.Vips.Operation.math2/3","doc":"Binary math operations","ref":"Vix.Vips.Operation.html#math2/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * math2 - Math to perform","ref":"Vix.Vips.Operation.html#math2/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math2!/3","doc":"Binary math operations","ref":"Vix.Vips.Operation.html#math2!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * math2 - Math to perform","ref":"Vix.Vips.Operation.html#math2!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math2_const/3","doc":"Binary math operations with a constant","ref":"Vix.Vips.Operation.html#math2_const/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2_const/3","doc":"* input - Input image\n  * math2 - Math to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#math2_const/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math2_const!/3","doc":"Binary math operations with a constant","ref":"Vix.Vips.Operation.html#math2_const!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2_const!/3","doc":"* input - Input image\n  * math2 - Math to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#math2_const!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math/2","doc":"Apply a math operation to an image","ref":"Vix.Vips.Operation.html#math/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math/2","doc":"* input - Input image\n  * math - Math to perform","ref":"Vix.Vips.Operation.html#math/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.math!/2","doc":"Apply a math operation to an image","ref":"Vix.Vips.Operation.html#math!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math!/2","doc":"* input - Input image\n  * math - Math to perform","ref":"Vix.Vips.Operation.html#math!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.matrixinvert/1","doc":"Invert an matrix","ref":"Vix.Vips.Operation.html#matrixinvert/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixinvert/1","doc":"* input - An square matrix","ref":"Vix.Vips.Operation.html#matrixinvert/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.matrixinvert!/1","doc":"Invert an matrix","ref":"Vix.Vips.Operation.html#matrixinvert!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixinvert!/1","doc":"* input - An square matrix","ref":"Vix.Vips.Operation.html#matrixinvert!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.matrixload/2","doc":"Load matrix","ref":"Vix.Vips.Operation.html#matrixload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#matrixload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#matrixload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.matrixload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#matrixload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.matrixload!/2","doc":"Load matrix","ref":"Vix.Vips.Operation.html#matrixload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#matrixload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#matrixload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.matrixload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#matrixload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.matrixprint/2","doc":"Print matrix","ref":"Vix.Vips.Operation.html#matrixprint/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixprint/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#matrixprint/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixprint/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixprint/2-optional"},{"type":"function","title":"Vix.Vips.Operation.matrixprint!/2","doc":"Print matrix","ref":"Vix.Vips.Operation.html#matrixprint!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixprint!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#matrixprint!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixprint!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixprint!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.matrixsave/3","doc":"Save image to matrix","ref":"Vix.Vips.Operation.html#matrixsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#matrixsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.matrixsave!/3","doc":"Save image to matrix","ref":"Vix.Vips.Operation.html#matrixsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#matrixsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.max/2","doc":"Find image maximum","ref":"Vix.Vips.Operation.html#max/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.max/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#max/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.max/2","doc":"* size - Number of maximum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#max/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.max/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of maximum. (`integer()`)\n* x - Horizontal position of maximum. (`integer()`)","ref":"Vix.Vips.Operation.html#max/2-returns"},{"type":"function","title":"Vix.Vips.Operation.max!/2","doc":"Find image maximum","ref":"Vix.Vips.Operation.html#max!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.max!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#max!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.max!/2","doc":"* size - Number of maximum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#max!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.max!/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of maximum. (`integer()`)\n* x - Horizontal position of maximum. (`integer()`)","ref":"Vix.Vips.Operation.html#max!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.measure/4","doc":"Measure a set of patches on a color chart","ref":"Vix.Vips.Operation.html#measure/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.measure/4","doc":"* input - Image to measure\n  * h - Number of patches across chart\n  * v - Number of patches down chart","ref":"Vix.Vips.Operation.html#measure/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.measure/4","doc":"* height - Height of extract area. Default: `1`\n* width - Width of extract area. Default: `1`\n* top - Top edge of extract area. Default: `0`\n* left - Left edge of extract area. Default: `0`","ref":"Vix.Vips.Operation.html#measure/4-optional"},{"type":"function","title":"Vix.Vips.Operation.measure!/4","doc":"Measure a set of patches on a color chart","ref":"Vix.Vips.Operation.html#measure!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.measure!/4","doc":"* input - Image to measure\n  * h - Number of patches across chart\n  * v - Number of patches down chart","ref":"Vix.Vips.Operation.html#measure!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.measure!/4","doc":"* height - Height of extract area. Default: `1`\n* width - Width of extract area. Default: `1`\n* top - Top edge of extract area. Default: `0`\n* left - Left edge of extract area. Default: `0`","ref":"Vix.Vips.Operation.html#measure!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.merge/6","doc":"Merge two images","ref":"Vix.Vips.Operation.html#merge/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.merge/6","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical merge\n  * dx - Horizontal displacement from sec to ref\n  * dy - Vertical displacement from sec to ref","ref":"Vix.Vips.Operation.html#merge/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.merge/6","doc":"* mblend - Maximum blend size. Default: `10`","ref":"Vix.Vips.Operation.html#merge/6-optional"},{"type":"function","title":"Vix.Vips.Operation.merge!/6","doc":"Merge two images","ref":"Vix.Vips.Operation.html#merge!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.merge!/6","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical merge\n  * dx - Horizontal displacement from sec to ref\n  * dy - Vertical displacement from sec to ref","ref":"Vix.Vips.Operation.html#merge!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.merge!/6","doc":"* mblend - Maximum blend size. Default: `10`","ref":"Vix.Vips.Operation.html#merge!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.min/2","doc":"Find image minimum","ref":"Vix.Vips.Operation.html#min/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.min/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#min/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.min/2","doc":"* size - Number of minimum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#min/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.min/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of minimum. (`integer()`)\n* x - Horizontal position of minimum. (`integer()`)","ref":"Vix.Vips.Operation.html#min/2-returns"},{"type":"function","title":"Vix.Vips.Operation.min!/2","doc":"Find image minimum","ref":"Vix.Vips.Operation.html#min!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.min!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#min!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.min!/2","doc":"* size - Number of minimum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#min!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.min!/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of minimum. (`integer()`)\n* x - Horizontal position of minimum. (`integer()`)","ref":"Vix.Vips.Operation.html#min!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.morph/3","doc":"Morphology operation","ref":"Vix.Vips.Operation.html#morph/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.morph/3","doc":"* input - Input image argument\n  * mask - Input matrix image\n  * morph - Morphological operation to perform","ref":"Vix.Vips.Operation.html#morph/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.morph!/3","doc":"Morphology operation","ref":"Vix.Vips.Operation.html#morph!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.morph!/3","doc":"* input - Input image argument\n  * mask - Input matrix image\n  * morph - Morphological operation to perform","ref":"Vix.Vips.Operation.html#morph!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.mosaic1/12","doc":"First-order mosaic of two images","ref":"Vix.Vips.Operation.html#mosaic1/12"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic1/12","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic1/12-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic1/12","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic1/12-optional"},{"type":"function","title":"Vix.Vips.Operation.mosaic1!/12","doc":"First-order mosaic of two images","ref":"Vix.Vips.Operation.html#mosaic1!/12"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic1!/12","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic1!/12-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic1!/12","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic1!/12-optional"},{"type":"function","title":"Vix.Vips.Operation.mosaic/8","doc":"Mosaic two images","ref":"Vix.Vips.Operation.html#mosaic/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic/8","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xref - Position of reference tie-point\n  * yref - Position of reference tie-point\n  * xsec - Position of secondary tie-point\n  * ysec - Position of secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic/8","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic/8-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.mosaic/8","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* dx1 - Detected first-order displacement. (`float()`)\n* dy1 - Detected first-order displacement. (`float()`)\n* angle1 - Detected rotation. (`float()`)\n* scale1 - Detected scale. (`float()`)\n* dy0 - Detected integer offset. (`integer()`)\n* dx0 - Detected integer offset. (`integer()`)","ref":"Vix.Vips.Operation.html#mosaic/8-returns"},{"type":"function","title":"Vix.Vips.Operation.mosaic!/8","doc":"Mosaic two images","ref":"Vix.Vips.Operation.html#mosaic!/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic!/8","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xref - Position of reference tie-point\n  * yref - Position of reference tie-point\n  * xsec - Position of secondary tie-point\n  * ysec - Position of secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic!/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic!/8","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic!/8-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.mosaic!/8","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* dx1 - Detected first-order displacement. (`float()`)\n* dy1 - Detected first-order displacement. (`float()`)\n* angle1 - Detected rotation. (`float()`)\n* scale1 - Detected scale. (`float()`)\n* dy0 - Detected integer offset. (`integer()`)\n* dx0 - Detected integer offset. (`integer()`)","ref":"Vix.Vips.Operation.html#mosaic!/8-returns"},{"type":"function","title":"Vix.Vips.Operation.msb/2","doc":"Pick most-significant byte from an image","ref":"Vix.Vips.Operation.html#msb/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.msb/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#msb/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.msb/2","doc":"* band - Band to msb. Default: `0`","ref":"Vix.Vips.Operation.html#msb/2-optional"},{"type":"function","title":"Vix.Vips.Operation.msb!/2","doc":"Pick most-significant byte from an image","ref":"Vix.Vips.Operation.html#msb!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.msb!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#msb!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.msb!/2","doc":"* band - Band to msb. Default: `0`","ref":"Vix.Vips.Operation.html#msb!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.multiply/2","doc":"Multiply two images","ref":"Vix.Vips.Operation.html#multiply/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.multiply/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#multiply/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.multiply!/2","doc":"Multiply two images","ref":"Vix.Vips.Operation.html#multiply!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.multiply!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#multiply!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.percent/2","doc":"Find threshold for percent of pixels","ref":"Vix.Vips.Operation.html#percent/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.percent/2","doc":"* input - Input image\n  * percent - Percent of pixels","ref":"Vix.Vips.Operation.html#percent/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.percent!/2","doc":"Find threshold for percent of pixels","ref":"Vix.Vips.Operation.html#percent!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.percent!/2","doc":"* input - Input image\n  * percent - Percent of pixels","ref":"Vix.Vips.Operation.html#percent!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.perlin/3","doc":"Make a perlin noise image","ref":"Vix.Vips.Operation.html#perlin/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.perlin/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#perlin/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.perlin/3","doc":"* seed - Random number seed. Default: `0`\n* uchar - Output an unsigned char image. Default: `false`\n* cell-size - Size of Perlin cells. Default: `256`","ref":"Vix.Vips.Operation.html#perlin/3-optional"},{"type":"function","title":"Vix.Vips.Operation.perlin!/3","doc":"Make a perlin noise image","ref":"Vix.Vips.Operation.html#perlin!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.perlin!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#perlin!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.perlin!/3","doc":"* seed - Random number seed. Default: `0`\n* uchar - Output an unsigned char image. Default: `false`\n* cell-size - Size of Perlin cells. Default: `256`","ref":"Vix.Vips.Operation.html#perlin!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.phasecor/2","doc":"Calculate phase correlation","ref":"Vix.Vips.Operation.html#phasecor/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.phasecor/2","doc":"* input - Input image\n  * in2 - Second input image","ref":"Vix.Vips.Operation.html#phasecor/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.phasecor!/2","doc":"Calculate phase correlation","ref":"Vix.Vips.Operation.html#phasecor!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.phasecor!/2","doc":"* input - Input image\n  * in2 - Second input image","ref":"Vix.Vips.Operation.html#phasecor!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.pngload/2","doc":"Load png from file","ref":"Vix.Vips.Operation.html#pngload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#pngload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngload!/2","doc":"Load png from file","ref":"Vix.Vips.Operation.html#pngload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#pngload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngload_buffer/2","doc":"Load png from buffer","ref":"Vix.Vips.Operation.html#pngload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#pngload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngload_buffer!/2","doc":"Load png from buffer","ref":"Vix.Vips.Operation.html#pngload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#pngload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngsave/3","doc":"Save image to file as png","ref":"Vix.Vips.Operation.html#pngsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#pngsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.pngsave!/3","doc":"Save image to file as png","ref":"Vix.Vips.Operation.html#pngsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#pngsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.pngsave_buffer/2","doc":"Save image to buffer as png","ref":"Vix.Vips.Operation.html#pngsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#pngsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.pngsave_buffer!/2","doc":"Save image to buffer as png","ref":"Vix.Vips.Operation.html#pngsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#pngsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.premultiply/2","doc":"Premultiply image alpha","ref":"Vix.Vips.Operation.html#premultiply/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.premultiply/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#premultiply/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.premultiply/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#premultiply/2-optional"},{"type":"function","title":"Vix.Vips.Operation.premultiply!/2","doc":"Premultiply image alpha","ref":"Vix.Vips.Operation.html#premultiply!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.premultiply!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#premultiply!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.premultiply!/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#premultiply!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.prewitt/1","doc":"Prewitt edge detector","ref":"Vix.Vips.Operation.html#prewitt/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.prewitt/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#prewitt/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.prewitt!/1","doc":"Prewitt edge detector","ref":"Vix.Vips.Operation.html#prewitt!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.prewitt!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#prewitt!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.profile/1","doc":"Find image profiles","ref":"Vix.Vips.Operation.html#profile/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#profile/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.profile/1","doc":"Operation returns a tuple\n\n* columns - First non-zero pixel in column. (`Vix.Vips.Image.t()`)\n* rows - First non-zero pixel in row. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#profile/1-returns"},{"type":"function","title":"Vix.Vips.Operation.profile!/1","doc":"Find image profiles","ref":"Vix.Vips.Operation.html#profile!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#profile!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.profile!/1","doc":"Operation returns a tuple\n\n* columns - First non-zero pixel in column. (`Vix.Vips.Image.t()`)\n* rows - First non-zero pixel in row. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#profile!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.profile_load/1","doc":"Load named icc profile","ref":"Vix.Vips.Operation.html#profile_load/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile_load/1","doc":"* name - Profile name","ref":"Vix.Vips.Operation.html#profile_load/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.profile_load!/1","doc":"Load named icc profile","ref":"Vix.Vips.Operation.html#profile_load!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile_load!/1","doc":"* name - Profile name","ref":"Vix.Vips.Operation.html#profile_load!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.project/1","doc":"Find image projections","ref":"Vix.Vips.Operation.html#project/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.project/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#project/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.project/1","doc":"Operation returns a tuple\n\n* columns - Sums of columns. (`Vix.Vips.Image.t()`)\n* rows - Sums of rows. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#project/1-returns"},{"type":"function","title":"Vix.Vips.Operation.project!/1","doc":"Find image projections","ref":"Vix.Vips.Operation.html#project!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.project!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#project!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.project!/1","doc":"Operation returns a tuple\n\n* columns - Sums of columns. (`Vix.Vips.Image.t()`)\n* rows - Sums of rows. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#project!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.quadratic/3","doc":"Resample an image with a quadratic transform","ref":"Vix.Vips.Operation.html#quadratic/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.quadratic/3","doc":"* input - Input image argument\n  * coeff - Coefficient matrix","ref":"Vix.Vips.Operation.html#quadratic/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.quadratic/3","doc":"* interpolate - Interpolate values with this.","ref":"Vix.Vips.Operation.html#quadratic/3-optional"},{"type":"function","title":"Vix.Vips.Operation.quadratic!/3","doc":"Resample an image with a quadratic transform","ref":"Vix.Vips.Operation.html#quadratic!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.quadratic!/3","doc":"* input - Input image argument\n  * coeff - Coefficient matrix","ref":"Vix.Vips.Operation.html#quadratic!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.quadratic!/3","doc":"* interpolate - Interpolate values with this.","ref":"Vix.Vips.Operation.html#quadratic!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rad2float/1","doc":"Unpack radiance coding to float rgb","ref":"Vix.Vips.Operation.html#rad2float/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rad2float/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rad2float/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.rad2float!/1","doc":"Unpack radiance coding to float rgb","ref":"Vix.Vips.Operation.html#rad2float!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rad2float!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rad2float!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.rank/4","doc":"Rank filter","ref":"Vix.Vips.Operation.html#rank/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rank/4","doc":"* input - Input image argument\n  * width - Window width in pixels\n  * height - Window height in pixels\n  * index - Select pixel at index","ref":"Vix.Vips.Operation.html#rank/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.rank!/4","doc":"Rank filter","ref":"Vix.Vips.Operation.html#rank!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rank!/4","doc":"* input - Input image argument\n  * width - Window width in pixels\n  * height - Window height in pixels\n  * index - Select pixel at index","ref":"Vix.Vips.Operation.html#rank!/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.rawload/5","doc":"Load raw data from a file","ref":"Vix.Vips.Operation.html#rawload/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawload/5","doc":"* filename - Filename to load from\n  * width - Image width in pixels\n  * height - Image height in pixels\n  * bands - Number of bands in image","ref":"Vix.Vips.Operation.html#rawload/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawload/5","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* offset - Offset in bytes from start of file. Default: `0`","ref":"Vix.Vips.Operation.html#rawload/5-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.rawload/5","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#rawload/5-returns"},{"type":"function","title":"Vix.Vips.Operation.rawload!/5","doc":"Load raw data from a file","ref":"Vix.Vips.Operation.html#rawload!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawload!/5","doc":"* filename - Filename to load from\n  * width - Image width in pixels\n  * height - Image height in pixels\n  * bands - Number of bands in image","ref":"Vix.Vips.Operation.html#rawload!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawload!/5","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* offset - Offset in bytes from start of file. Default: `0`","ref":"Vix.Vips.Operation.html#rawload!/5-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.rawload!/5","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#rawload!/5-returns"},{"type":"function","title":"Vix.Vips.Operation.rawsave/3","doc":"Save image to raw file","ref":"Vix.Vips.Operation.html#rawsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#rawsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rawsave!/3","doc":"Save image to raw file","ref":"Vix.Vips.Operation.html#rawsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#rawsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rawsave_fd/3","doc":"Write raw image to file descriptor","ref":"Vix.Vips.Operation.html#rawsave_fd/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave_fd/3","doc":"* input - Image to save\n  * fd - File descriptor to write to","ref":"Vix.Vips.Operation.html#rawsave_fd/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave_fd/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave_fd/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rawsave_fd!/3","doc":"Write raw image to file descriptor","ref":"Vix.Vips.Operation.html#rawsave_fd!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave_fd!/3","doc":"* input - Image to save\n  * fd - File descriptor to write to","ref":"Vix.Vips.Operation.html#rawsave_fd!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave_fd!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave_fd!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.recomb/2","doc":"Linear recombination with matrix","ref":"Vix.Vips.Operation.html#recomb/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.recomb/2","doc":"* input - Input image argument\n  * m - Matrix of coefficients","ref":"Vix.Vips.Operation.html#recomb/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.recomb!/2","doc":"Linear recombination with matrix","ref":"Vix.Vips.Operation.html#recomb!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.recomb!/2","doc":"* input - Input image argument\n  * m - Matrix of coefficients","ref":"Vix.Vips.Operation.html#recomb!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.reduce/4","doc":"Reduce an image","ref":"Vix.Vips.Operation.html#reduce/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduce/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reduce/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduce/4","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduce/4-optional"},{"type":"function","title":"Vix.Vips.Operation.reduce!/4","doc":"Reduce an image","ref":"Vix.Vips.Operation.html#reduce!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduce!/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reduce!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduce!/4","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduce!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.reduceh/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#reduceh/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduceh/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#reduceh/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduceh/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduceh/3-optional"},{"type":"function","title":"Vix.Vips.Operation.reduceh!/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#reduceh!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduceh!/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#reduceh!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduceh!/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduceh!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.reducev/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#reducev/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reducev/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reducev/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reducev/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reducev/3-optional"},{"type":"function","title":"Vix.Vips.Operation.reducev!/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#reducev!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reducev!/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reducev!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reducev!/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reducev!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.relational/3","doc":"Relational operation on two images","ref":"Vix.Vips.Operation.html#relational/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * relational - Relational to perform","ref":"Vix.Vips.Operation.html#relational/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.relational!/3","doc":"Relational operation on two images","ref":"Vix.Vips.Operation.html#relational!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * relational - Relational to perform","ref":"Vix.Vips.Operation.html#relational!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.relational_const/3","doc":"Relational operations against a constant","ref":"Vix.Vips.Operation.html#relational_const/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational_const/3","doc":"* input - Input image\n  * relational - Relational to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#relational_const/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.relational_const!/3","doc":"Relational operations against a constant","ref":"Vix.Vips.Operation.html#relational_const!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational_const!/3","doc":"* input - Input image\n  * relational - Relational to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#relational_const!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder/2","doc":"Remainder after integer division of two images","ref":"Vix.Vips.Operation.html#remainder/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#remainder/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder!/2","doc":"Remainder after integer division of two images","ref":"Vix.Vips.Operation.html#remainder!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#remainder!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder_const/2","doc":"Remainder after integer division of an image and a constant","ref":"Vix.Vips.Operation.html#remainder_const/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder_const/2","doc":"* input - Input image\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#remainder_const/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder_const!/2","doc":"Remainder after integer division of an image and a constant","ref":"Vix.Vips.Operation.html#remainder_const!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder_const!/2","doc":"* input - Input image\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#remainder_const!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.replicate/3","doc":"Replicate an image","ref":"Vix.Vips.Operation.html#replicate/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.replicate/3","doc":"* input - Input image\n  * across - Repeat this many times horizontally\n  * down - Repeat this many times vertically","ref":"Vix.Vips.Operation.html#replicate/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.replicate!/3","doc":"Replicate an image","ref":"Vix.Vips.Operation.html#replicate!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.replicate!/3","doc":"* input - Input image\n  * across - Repeat this many times horizontally\n  * down - Repeat this many times vertically","ref":"Vix.Vips.Operation.html#replicate!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.resize/3","doc":"Resize an image","ref":"Vix.Vips.Operation.html#resize/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.resize/3","doc":"* input - Input image argument\n  * scale - Scale image by this factor","ref":"Vix.Vips.Operation.html#resize/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.resize/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* vscale - Vertical scale image by this factor. Default: `0.0`\n* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `2.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#resize/3-optional"},{"type":"function","title":"Vix.Vips.Operation.resize!/3","doc":"Resize an image","ref":"Vix.Vips.Operation.html#resize!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.resize!/3","doc":"* input - Input image argument\n  * scale - Scale image by this factor","ref":"Vix.Vips.Operation.html#resize!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.resize!/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* vscale - Vertical scale image by this factor. Default: `0.0`\n* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `2.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#resize!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rot45/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot45/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot45/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rot45/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rot45/2","doc":"* angle - Angle to rotate image. Default: `:VIPS_ANGLE45_D45`","ref":"Vix.Vips.Operation.html#rot45/2-optional"},{"type":"function","title":"Vix.Vips.Operation.rot45!/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot45!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot45!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rot45!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rot45!/2","doc":"* angle - Angle to rotate image. Default: `:VIPS_ANGLE45_D45`","ref":"Vix.Vips.Operation.html#rot45!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.rot/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot/2","doc":"* input - Input image\n  * angle - Angle to rotate image","ref":"Vix.Vips.Operation.html#rot/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.rot!/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot!/2","doc":"* input - Input image\n  * angle - Angle to rotate image","ref":"Vix.Vips.Operation.html#rot!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.rotate/3","doc":"Rotate an image by a number of degrees","ref":"Vix.Vips.Operation.html#rotate/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rotate/3","doc":"* input - Input image argument\n  * angle - Rotate anticlockwise by this many degrees","ref":"Vix.Vips.Operation.html#rotate/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rotate/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#rotate/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rotate!/3","doc":"Rotate an image by a number of degrees","ref":"Vix.Vips.Operation.html#rotate!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rotate!/3","doc":"* input - Input image argument\n  * angle - Rotate anticlockwise by this many degrees","ref":"Vix.Vips.Operation.html#rotate!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rotate!/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#rotate!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.round/2","doc":"Perform a round function on an image","ref":"Vix.Vips.Operation.html#round/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.round/2","doc":"* input - Input image\n  * round - Rounding operation to perform","ref":"Vix.Vips.Operation.html#round/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.round!/2","doc":"Perform a round function on an image","ref":"Vix.Vips.Operation.html#round!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.round!/2","doc":"* input - Input image\n  * round - Rounding operation to perform","ref":"Vix.Vips.Operation.html#round!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.scale/2","doc":"Scale an image to uchar","ref":"Vix.Vips.Operation.html#scale/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scale/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scale/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scale/2","doc":"* log - Log scale. Default: `false`\n* exp - Exponent for log scale. Default: `0.25`","ref":"Vix.Vips.Operation.html#scale/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scale!/2","doc":"Scale an image to uchar","ref":"Vix.Vips.Operation.html#scale!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scale!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scale!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scale!/2","doc":"* log - Log scale. Default: `false`\n* exp - Exponent for log scale. Default: `0.25`","ref":"Vix.Vips.Operation.html#scale!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scharr/1","doc":"Scharr edge detector","ref":"Vix.Vips.Operation.html#scharr/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scharr/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scharr/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.scharr!/1","doc":"Scharr edge detector","ref":"Vix.Vips.Operation.html#scharr!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scharr!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scharr!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.scrgb2bw/2","doc":"Convert scrgb to bw","ref":"Vix.Vips.Operation.html#scrgb2bw/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2bw/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2bw/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2bw/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2bw/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2bw!/2","doc":"Convert scrgb to bw","ref":"Vix.Vips.Operation.html#scrgb2bw!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2bw!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2bw!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2bw!/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2bw!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2srgb/2","doc":"Convert an scrgb image to srgb","ref":"Vix.Vips.Operation.html#scrgb2srgb/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2srgb/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2srgb/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2srgb/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2srgb/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2srgb!/2","doc":"Convert an scrgb image to srgb","ref":"Vix.Vips.Operation.html#scrgb2srgb!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2srgb!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2srgb!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2srgb!/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2srgb!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2xyz/1","doc":"Transform scrgb to xyz","ref":"Vix.Vips.Operation.html#scrgb2xyz/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2xyz/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2xyz/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.scrgb2xyz!/1","doc":"Transform scrgb to xyz","ref":"Vix.Vips.Operation.html#scrgb2xyz!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2xyz!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2xyz!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sequential/2","doc":"Check sequential access","ref":"Vix.Vips.Operation.html#sequential/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sequential/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sequential/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sequential/2","doc":"* access - Expected access pattern. Default: `:VIPS_ACCESS_SEQUENTIAL`\n* tile-height - Tile height in pixels. Default: `1`\n* trace - Trace pixel requests. Default: `true`","ref":"Vix.Vips.Operation.html#sequential/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sequential!/2","doc":"Check sequential access","ref":"Vix.Vips.Operation.html#sequential!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sequential!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sequential!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sequential!/2","doc":"* access - Expected access pattern. Default: `:VIPS_ACCESS_SEQUENTIAL`\n* tile-height - Tile height in pixels. Default: `1`\n* trace - Trace pixel requests. Default: `true`","ref":"Vix.Vips.Operation.html#sequential!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sharpen/2","doc":"Unsharp masking for print","ref":"Vix.Vips.Operation.html#sharpen/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sharpen/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sharpen/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sharpen/2","doc":"* m2 - Slope for jaggy areas. Default: `3.0`\n* m1 - Slope for flat areas. Default: `0.0`\n* y3 - Maximum darkening. Default: `20.0`\n* y2 - Maximum brightening. Default: `10.0`\n* x1 - Flat/jaggy threshold. Default: `2.0`\n* sigma - Sigma of Gaussian. Default: `0.5`\n* radius - Radius of Gaussian. Default: `1`","ref":"Vix.Vips.Operation.html#sharpen/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sharpen!/2","doc":"Unsharp masking for print","ref":"Vix.Vips.Operation.html#sharpen!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sharpen!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sharpen!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sharpen!/2","doc":"* m2 - Slope for jaggy areas. Default: `3.0`\n* m1 - Slope for flat areas. Default: `0.0`\n* y3 - Maximum darkening. Default: `20.0`\n* y2 - Maximum brightening. Default: `10.0`\n* x1 - Flat/jaggy threshold. Default: `2.0`\n* sigma - Sigma of Gaussian. Default: `0.5`\n* radius - Radius of Gaussian. Default: `1`","ref":"Vix.Vips.Operation.html#sharpen!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.shrink/4","doc":"Shrink an image","ref":"Vix.Vips.Operation.html#shrink/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrink/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrink/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrink/4","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrink/4-optional"},{"type":"function","title":"Vix.Vips.Operation.shrink!/4","doc":"Shrink an image","ref":"Vix.Vips.Operation.html#shrink!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrink!/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrink!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrink!/4","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrink!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkh/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#shrinkh/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkh/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#shrinkh/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkh/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkh/3-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkh!/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#shrinkh!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkh!/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#shrinkh!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkh!/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkh!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkv/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#shrinkv/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkv/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrinkv/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkv/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkv/3-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkv!/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#shrinkv!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkv!/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrinkv!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkv!/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkv!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.sign/1","doc":"Unit vector of pixel","ref":"Vix.Vips.Operation.html#sign/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sign/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sign/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sign!/1","doc":"Unit vector of pixel","ref":"Vix.Vips.Operation.html#sign!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sign!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sign!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.similarity/2","doc":"Similarity transform of an image","ref":"Vix.Vips.Operation.html#similarity/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.similarity/2","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#similarity/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.similarity/2","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this. \n* angle - Rotate anticlockwise by this many degrees. Default: `0.0`\n* scale - Scale by this factor. Default: `1.0`","ref":"Vix.Vips.Operation.html#similarity/2-optional"},{"type":"function","title":"Vix.Vips.Operation.similarity!/2","doc":"Similarity transform of an image","ref":"Vix.Vips.Operation.html#similarity!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.similarity!/2","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#similarity!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.similarity!/2","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this. \n* angle - Rotate anticlockwise by this many degrees. Default: `0.0`\n* scale - Scale by this factor. Default: `1.0`","ref":"Vix.Vips.Operation.html#similarity!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sines/3","doc":"Make a 2d sine wave","ref":"Vix.Vips.Operation.html#sines/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sines/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#sines/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sines/3","doc":"* vfreq - Vertical spatial frequency. Default: `0.5`\n* hfreq - Horizontal spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#sines/3-optional"},{"type":"function","title":"Vix.Vips.Operation.sines!/3","doc":"Make a 2d sine wave","ref":"Vix.Vips.Operation.html#sines!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sines!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#sines!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sines!/3","doc":"* vfreq - Vertical spatial frequency. Default: `0.5`\n* hfreq - Horizontal spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#sines!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.smartcrop/4","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#smartcrop/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.smartcrop/4","doc":"* input - Input image\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#smartcrop/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.smartcrop/4","doc":"* premultiplied - Input image already has premultiplied alpha. Default: `false`\n* interesting - How to measure interestingness. Default: `:VIPS_INTERESTING_ATTENTION`","ref":"Vix.Vips.Operation.html#smartcrop/4-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.smartcrop/4","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* attention-y - Vertical position of attention centre. (`integer()`)\n* attention-x - Horizontal position of attention centre. (`integer()`)","ref":"Vix.Vips.Operation.html#smartcrop/4-returns"},{"type":"function","title":"Vix.Vips.Operation.smartcrop!/4","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#smartcrop!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.smartcrop!/4","doc":"* input - Input image\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#smartcrop!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.smartcrop!/4","doc":"* premultiplied - Input image already has premultiplied alpha. Default: `false`\n* interesting - How to measure interestingness. Default: `:VIPS_INTERESTING_ATTENTION`","ref":"Vix.Vips.Operation.html#smartcrop!/4-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.smartcrop!/4","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* attention-y - Vertical position of attention centre. (`integer()`)\n* attention-x - Horizontal position of attention centre. (`integer()`)","ref":"Vix.Vips.Operation.html#smartcrop!/4-returns"},{"type":"function","title":"Vix.Vips.Operation.sobel/1","doc":"Sobel edge detector","ref":"Vix.Vips.Operation.html#sobel/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sobel/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sobel/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sobel!/1","doc":"Sobel edge detector","ref":"Vix.Vips.Operation.html#sobel!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sobel!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sobel!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.spcor/2","doc":"Spatial correlation","ref":"Vix.Vips.Operation.html#spcor/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spcor/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#spcor/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.spcor!/2","doc":"Spatial correlation","ref":"Vix.Vips.Operation.html#spcor!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spcor!/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#spcor!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.spectrum/1","doc":"Make displayable power spectrum","ref":"Vix.Vips.Operation.html#spectrum/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spectrum/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#spectrum/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.spectrum!/1","doc":"Make displayable power spectrum","ref":"Vix.Vips.Operation.html#spectrum!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spectrum!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#spectrum!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2hsv/1","doc":"Transform srgb to hsv","ref":"Vix.Vips.Operation.html#srgb2hsv/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2hsv/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2hsv/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2hsv!/1","doc":"Transform srgb to hsv","ref":"Vix.Vips.Operation.html#srgb2hsv!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2hsv!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2hsv!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2scrgb/1","doc":"Convert an srgb image to scrgb","ref":"Vix.Vips.Operation.html#srgb2scrgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2scrgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2scrgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2scrgb!/1","doc":"Convert an srgb image to scrgb","ref":"Vix.Vips.Operation.html#srgb2scrgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2scrgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2scrgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.stats/1","doc":"Find many image stats","ref":"Vix.Vips.Operation.html#stats/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stats/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#stats/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.stats!/1","doc":"Find many image stats","ref":"Vix.Vips.Operation.html#stats!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stats!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#stats!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.stdif/4","doc":"Statistical difference","ref":"Vix.Vips.Operation.html#stdif/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stdif/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#stdif/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.stdif/4","doc":"* a - Weight of new mean. Default: `0.5`\n* m0 - New mean. Default: `128.0`\n* b - Weight of new deviation. Default: `0.5`\n* s0 - New deviation. Default: `50.0`","ref":"Vix.Vips.Operation.html#stdif/4-optional"},{"type":"function","title":"Vix.Vips.Operation.stdif!/4","doc":"Statistical difference","ref":"Vix.Vips.Operation.html#stdif!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stdif!/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#stdif!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.stdif!/4","doc":"* a - Weight of new mean. Default: `0.5`\n* m0 - New mean. Default: `128.0`\n* b - Weight of new deviation. Default: `0.5`\n* s0 - New deviation. Default: `50.0`","ref":"Vix.Vips.Operation.html#stdif!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.subsample/4","doc":"Subsample an image","ref":"Vix.Vips.Operation.html#subsample/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subsample/4","doc":"* input - Input image\n  * xfac - Horizontal subsample factor\n  * yfac - Vertical subsample factor","ref":"Vix.Vips.Operation.html#subsample/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.subsample/4","doc":"* point - Point sample. Default: `false`","ref":"Vix.Vips.Operation.html#subsample/4-optional"},{"type":"function","title":"Vix.Vips.Operation.subsample!/4","doc":"Subsample an image","ref":"Vix.Vips.Operation.html#subsample!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subsample!/4","doc":"* input - Input image\n  * xfac - Horizontal subsample factor\n  * yfac - Vertical subsample factor","ref":"Vix.Vips.Operation.html#subsample!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.subsample!/4","doc":"* point - Point sample. Default: `false`","ref":"Vix.Vips.Operation.html#subsample!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.subtract/2","doc":"Subtract two images","ref":"Vix.Vips.Operation.html#subtract/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subtract/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#subtract/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.subtract!/2","doc":"Subtract two images","ref":"Vix.Vips.Operation.html#subtract!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subtract!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#subtract!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.sum/1","doc":"Sum an array of images","ref":"Vix.Vips.Operation.html#sum/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sum/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#sum/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sum!/1","doc":"Sum an array of images","ref":"Vix.Vips.Operation.html#sum!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sum!/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#sum!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.svgload/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#svgload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.svgload!/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#svgload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.svgload_buffer/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#svgload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.svgload_buffer!/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#svgload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.switch/1","doc":"Find the index of the first non-zero pixel in tests","ref":"Vix.Vips.Operation.html#switch/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.switch/1","doc":"* tests - Table of images to test","ref":"Vix.Vips.Operation.html#switch/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.switch!/1","doc":"Find the index of the first non-zero pixel in tests","ref":"Vix.Vips.Operation.html#switch!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.switch!/1","doc":"* tests - Table of images to test","ref":"Vix.Vips.Operation.html#switch!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.system/2","doc":"Run an external command","ref":"Vix.Vips.Operation.html#system/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.system/2","doc":"* cmd-format - Command to run","ref":"Vix.Vips.Operation.html#system/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.system/2","doc":"* in-format - Format for input filename. Default: `nil`\n* out-format - Format for output filename. Default: `nil`\n* in - Array of input images. Default: `nil`","ref":"Vix.Vips.Operation.html#system/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.system/2","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* log - Command log. (`String.t()`)\n* out - Output image. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#system/2-returns"},{"type":"function","title":"Vix.Vips.Operation.system!/2","doc":"Run an external command","ref":"Vix.Vips.Operation.html#system!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.system!/2","doc":"* cmd-format - Command to run","ref":"Vix.Vips.Operation.html#system!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.system!/2","doc":"* in-format - Format for input filename. Default: `nil`\n* out-format - Format for output filename. Default: `nil`\n* in - Array of input images. Default: `nil`","ref":"Vix.Vips.Operation.html#system!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.system!/2","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* log - Command log. (`String.t()`)\n* out - Output image. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#system!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.text/2","doc":"Make a text image","ref":"Vix.Vips.Operation.html#text/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.text/2","doc":"* text - Text to render","ref":"Vix.Vips.Operation.html#text/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.text/2","doc":"* wrap - Wrap lines on word or character boundaries. Default: `:VIPS_TEXT_WRAP_WORD`\n* rgba - Enable RGBA output. Default: `false`\n* fontfile - Load this font file. Default: `nil`\n* spacing - Line spacing. Default: `0`\n* dpi - DPI to render at. Default: `72`\n* justify - Justify lines. Default: `false`\n* align - Align on the low, centre or high edge. Default: `:VIPS_ALIGN_LOW`\n* height - Maximum image height in pixels. Default: `0`\n* width - Maximum image width in pixels. Default: `0`\n* font - Font to render with. Default: `nil`","ref":"Vix.Vips.Operation.html#text/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.text/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* autofit-dpi - DPI selected by autofit. (`integer()`)","ref":"Vix.Vips.Operation.html#text/2-returns"},{"type":"function","title":"Vix.Vips.Operation.text!/2","doc":"Make a text image","ref":"Vix.Vips.Operation.html#text!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.text!/2","doc":"* text - Text to render","ref":"Vix.Vips.Operation.html#text!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.text!/2","doc":"* wrap - Wrap lines on word or character boundaries. Default: `:VIPS_TEXT_WRAP_WORD`\n* rgba - Enable RGBA output. Default: `false`\n* fontfile - Load this font file. Default: `nil`\n* spacing - Line spacing. Default: `0`\n* dpi - DPI to render at. Default: `72`\n* justify - Justify lines. Default: `false`\n* align - Align on the low, centre or high edge. Default: `:VIPS_ALIGN_LOW`\n* height - Maximum image height in pixels. Default: `0`\n* width - Maximum image width in pixels. Default: `0`\n* font - Font to render with. Default: `nil`","ref":"Vix.Vips.Operation.html#text!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.text!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* autofit-dpi - DPI selected by autofit. (`integer()`)","ref":"Vix.Vips.Operation.html#text!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.thumbnail/3","doc":"Generate thumbnail from file","ref":"Vix.Vips.Operation.html#thumbnail/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail/3","doc":"* filename - Filename to read from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail!/3","doc":"Generate thumbnail from file","ref":"Vix.Vips.Operation.html#thumbnail!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail!/3","doc":"* filename - Filename to read from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail!/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_buffer/3","doc":"Generate thumbnail from buffer","ref":"Vix.Vips.Operation.html#thumbnail_buffer/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_buffer/3","doc":"* buffer - Buffer to load from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_buffer/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_buffer/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`\n* option-string - Options that are passed on to the underlying loader. Default: `\"\"`","ref":"Vix.Vips.Operation.html#thumbnail_buffer/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_buffer!/3","doc":"Generate thumbnail from buffer","ref":"Vix.Vips.Operation.html#thumbnail_buffer!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_buffer!/3","doc":"* buffer - Buffer to load from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_buffer!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_buffer!/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`\n* option-string - Options that are passed on to the underlying loader. Default: `\"\"`","ref":"Vix.Vips.Operation.html#thumbnail_buffer!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_image/3","doc":"Generate thumbnail from image","ref":"Vix.Vips.Operation.html#thumbnail_image/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_image/3","doc":"* input - Input image argument\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_image/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_image/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail_image/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_image!/3","doc":"Generate thumbnail from image","ref":"Vix.Vips.Operation.html#thumbnail_image!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_image!/3","doc":"* input - Input image argument\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_image!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_image!/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail_image!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffload/2","doc":"Load tiff from file","ref":"Vix.Vips.Operation.html#tiffload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#tiffload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffload!/2","doc":"Load tiff from file","ref":"Vix.Vips.Operation.html#tiffload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#tiffload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffload_buffer/2","doc":"Load tiff from buffer","ref":"Vix.Vips.Operation.html#tiffload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#tiffload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffload_buffer!/2","doc":"Load tiff from buffer","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffsave/3","doc":"Save image to tiff file","ref":"Vix.Vips.Operation.html#tiffsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#tiffsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffsave!/3","doc":"Save image to tiff file","ref":"Vix.Vips.Operation.html#tiffsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#tiffsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffsave_buffer/2","doc":"Save image to tiff buffer","ref":"Vix.Vips.Operation.html#tiffsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#tiffsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffsave_buffer!/2","doc":"Save image to tiff buffer","ref":"Vix.Vips.Operation.html#tiffsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#tiffsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tilecache/2","doc":"Cache an image as a set of tiles","ref":"Vix.Vips.Operation.html#tilecache/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tilecache/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#tilecache/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tilecache/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#tilecache/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tilecache!/2","doc":"Cache an image as a set of tiles","ref":"Vix.Vips.Operation.html#tilecache!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tilecache!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#tilecache!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tilecache!/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#tilecache!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tonelut/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#tonelut/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tonelut/1","doc":"","ref":"Vix.Vips.Operation.html#tonelut/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tonelut/1","doc":"* H - Adjust highlights by this much. Default: `0.0`\n* M - Adjust mid-tones by this much. Default: `0.0`\n* S - Adjust shadows by this much. Default: `0.0`\n* Ph - Position of highlights. Default: `0.8`\n* Pm - Position of mid-tones. Default: `0.5`\n* Ps - Position of shadow. Default: `0.2`\n* Lw - Highest value in output. Default: `100.0`\n* Lb - Lowest value in output. Default: `0.0`\n* out-max - Maximum value in output LUT. Default: `32767`\n* in-max - Size of LUT to build. Default: `32767`","ref":"Vix.Vips.Operation.html#tonelut/1-optional"},{"type":"function","title":"Vix.Vips.Operation.tonelut!/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#tonelut!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tonelut!/1","doc":"","ref":"Vix.Vips.Operation.html#tonelut!/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tonelut!/1","doc":"* H - Adjust highlights by this much. Default: `0.0`\n* M - Adjust mid-tones by this much. Default: `0.0`\n* S - Adjust shadows by this much. Default: `0.0`\n* Ph - Position of highlights. Default: `0.8`\n* Pm - Position of mid-tones. Default: `0.5`\n* Ps - Position of shadow. Default: `0.2`\n* Lw - Highest value in output. Default: `100.0`\n* Lb - Lowest value in output. Default: `0.0`\n* out-max - Maximum value in output LUT. Default: `32767`\n* in-max - Size of LUT to build. Default: `32767`","ref":"Vix.Vips.Operation.html#tonelut!/1-optional"},{"type":"function","title":"Vix.Vips.Operation.transpose3d/2","doc":"Transpose3d an image","ref":"Vix.Vips.Operation.html#transpose3d/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.transpose3d/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#transpose3d/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.transpose3d/2","doc":"* page-height - Height of each input page. Default: `0`","ref":"Vix.Vips.Operation.html#transpose3d/2-optional"},{"type":"function","title":"Vix.Vips.Operation.transpose3d!/2","doc":"Transpose3d an image","ref":"Vix.Vips.Operation.html#transpose3d!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.transpose3d!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#transpose3d!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.transpose3d!/2","doc":"* page-height - Height of each input page. Default: `0`","ref":"Vix.Vips.Operation.html#transpose3d!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.unpremultiply/2","doc":"Unpremultiply image alpha","ref":"Vix.Vips.Operation.html#unpremultiply/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.unpremultiply/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#unpremultiply/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.unpremultiply/2","doc":"* alpha-band - Unpremultiply with this alpha. Default: `3`\n* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#unpremultiply/2-optional"},{"type":"function","title":"Vix.Vips.Operation.unpremultiply!/2","doc":"Unpremultiply image alpha","ref":"Vix.Vips.Operation.html#unpremultiply!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.unpremultiply!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#unpremultiply!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.unpremultiply!/2","doc":"* alpha-band - Unpremultiply with this alpha. Default: `3`\n* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#unpremultiply!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.vipsload/2","doc":"Load vips from file","ref":"Vix.Vips.Operation.html#vipsload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipsload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#vipsload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipsload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#vipsload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.vipsload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#vipsload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.vipsload!/2","doc":"Load vips from file","ref":"Vix.Vips.Operation.html#vipsload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipsload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#vipsload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipsload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#vipsload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.vipsload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#vipsload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.vipssave/3","doc":"Save image to file in vips format","ref":"Vix.Vips.Operation.html#vipssave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipssave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#vipssave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipssave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#vipssave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.vipssave!/3","doc":"Save image to file in vips format","ref":"Vix.Vips.Operation.html#vipssave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipssave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#vipssave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipssave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#vipssave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.webpload/2","doc":"Load webp from file","ref":"Vix.Vips.Operation.html#webpload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#webpload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpload!/2","doc":"Load webp from file","ref":"Vix.Vips.Operation.html#webpload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#webpload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpload_buffer/2","doc":"Load webp from buffer","ref":"Vix.Vips.Operation.html#webpload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#webpload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpload_buffer!/2","doc":"Load webp from buffer","ref":"Vix.Vips.Operation.html#webpload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#webpload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpsave/3","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#webpsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave!/3","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#webpsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_buffer/2","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_buffer!/2","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_mime/2","doc":"Save image to webp mime","ref":"Vix.Vips.Operation.html#webpsave_mime/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_mime/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_mime/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_mime/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_mime/2-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_mime!/2","doc":"Save image to webp mime","ref":"Vix.Vips.Operation.html#webpsave_mime!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_mime!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_mime!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_mime!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_mime!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.worley/3","doc":"Make a worley noise image","ref":"Vix.Vips.Operation.html#worley/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.worley/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#worley/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.worley/3","doc":"* seed - Random number seed. Default: `0`\n* cell-size - Size of Worley cells. Default: `256`","ref":"Vix.Vips.Operation.html#worley/3-optional"},{"type":"function","title":"Vix.Vips.Operation.worley!/3","doc":"Make a worley noise image","ref":"Vix.Vips.Operation.html#worley!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.worley!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#worley!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.worley!/3","doc":"* seed - Random number seed. Default: `0`\n* cell-size - Size of Worley cells. Default: `256`","ref":"Vix.Vips.Operation.html#worley!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.wrap/2","doc":"Wrap image origin","ref":"Vix.Vips.Operation.html#wrap/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.wrap/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#wrap/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.wrap/2","doc":"* y - Top edge of input in output. Default: `0`\n* x - Left edge of input in output. Default: `0`","ref":"Vix.Vips.Operation.html#wrap/2-optional"},{"type":"function","title":"Vix.Vips.Operation.wrap!/2","doc":"Wrap image origin","ref":"Vix.Vips.Operation.html#wrap!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.wrap!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#wrap!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.wrap!/2","doc":"* y - Top edge of input in output. Default: `0`\n* x - Left edge of input in output. Default: `0`","ref":"Vix.Vips.Operation.html#wrap!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz2cmyk/1","doc":"Transform xyz to cmyk","ref":"Vix.Vips.Operation.html#xyz2cmyk/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2cmyk/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2cmyk/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2cmyk!/1","doc":"Transform xyz to cmyk","ref":"Vix.Vips.Operation.html#xyz2cmyk!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2cmyk!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2cmyk!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2lab/2","doc":"Transform xyz to lab","ref":"Vix.Vips.Operation.html#xyz2lab/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2lab/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2lab/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz2lab/2","doc":"* temp - Colour temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#xyz2lab/2-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz2lab!/2","doc":"Transform xyz to lab","ref":"Vix.Vips.Operation.html#xyz2lab!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2lab!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2lab!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz2lab!/2","doc":"* temp - Colour temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#xyz2lab!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz2scrgb/1","doc":"Transform xyz to scrgb","ref":"Vix.Vips.Operation.html#xyz2scrgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2scrgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2scrgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2scrgb!/1","doc":"Transform xyz to scrgb","ref":"Vix.Vips.Operation.html#xyz2scrgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2scrgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2scrgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2yxy/1","doc":"Transform xyz to yxy","ref":"Vix.Vips.Operation.html#xyz2yxy/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2yxy/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2yxy/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2yxy!/1","doc":"Transform xyz to yxy","ref":"Vix.Vips.Operation.html#xyz2yxy!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2yxy!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2yxy!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz/3","doc":"Make an image where pixel values are coordinates","ref":"Vix.Vips.Operation.html#xyz/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#xyz/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz/3","doc":"* esize - Size of fifth dimension. Default: `1`\n* dsize - Size of fourth dimension. Default: `1`\n* csize - Size of third dimension. Default: `1`","ref":"Vix.Vips.Operation.html#xyz/3-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz!/3","doc":"Make an image where pixel values are coordinates","ref":"Vix.Vips.Operation.html#xyz!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#xyz!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz!/3","doc":"* esize - Size of fifth dimension. Default: `1`\n* dsize - Size of fourth dimension. Default: `1`\n* csize - Size of third dimension. Default: `1`","ref":"Vix.Vips.Operation.html#xyz!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.yxy2xyz/1","doc":"Transform yxy to xyz","ref":"Vix.Vips.Operation.html#yxy2xyz/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.yxy2xyz/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#yxy2xyz/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.yxy2xyz!/1","doc":"Transform yxy to xyz","ref":"Vix.Vips.Operation.html#yxy2xyz!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.yxy2xyz!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#yxy2xyz!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.zone/3","doc":"Make a zone plate","ref":"Vix.Vips.Operation.html#zone/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zone/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#zone/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.zone/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#zone/3-optional"},{"type":"function","title":"Vix.Vips.Operation.zone!/3","doc":"Make a zone plate","ref":"Vix.Vips.Operation.html#zone!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zone!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#zone!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.zone!/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#zone!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.zoom/3","doc":"Zoom an image","ref":"Vix.Vips.Operation.html#zoom/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zoom/3","doc":"* input - Input image\n  * xfac - Horizontal zoom factor\n  * yfac - Vertical zoom factor","ref":"Vix.Vips.Operation.html#zoom/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.zoom!/3","doc":"Zoom an image","ref":"Vix.Vips.Operation.html#zoom!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zoom!/3","doc":"* input - Input image\n  * xfac - Horizontal zoom factor\n  * yfac - Vertical zoom factor","ref":"Vix.Vips.Operation.html#zoom!/3-arguments"},{"type":"type","title":"Vix.Vips.Operation.vips_access/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_access/0"},{"type":"type","title":"Vix.Vips.Operation.vips_align/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_align/0"},{"type":"type","title":"Vix.Vips.Operation.vips_angle45/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_angle45/0"},{"type":"type","title":"Vix.Vips.Operation.vips_angle/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_angle/0"},{"type":"type","title":"Vix.Vips.Operation.vips_band_format/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_band_format/0"},{"type":"type","title":"Vix.Vips.Operation.vips_blend_mode/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_blend_mode/0"},{"type":"type","title":"Vix.Vips.Operation.vips_coding/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_coding/0"},{"type":"type","title":"Vix.Vips.Operation.vips_combine/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_combine/0"},{"type":"type","title":"Vix.Vips.Operation.vips_combine_mode/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_combine_mode/0"},{"type":"type","title":"Vix.Vips.Operation.vips_compass_direction/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_compass_direction/0"},{"type":"type","title":"Vix.Vips.Operation.vips_demand_style/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_demand_style/0"},{"type":"type","title":"Vix.Vips.Operation.vips_direction/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_direction/0"},{"type":"type","title":"Vix.Vips.Operation.vips_extend/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_extend/0"},{"type":"type","title":"Vix.Vips.Operation.vips_fail_on/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_fail_on/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_dz_container/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_dz_container/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_dz_depth/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_dz_depth/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_dz_layout/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_dz_layout/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_flags/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_flags/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_heif_compression/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_heif_compression/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_heif_encoder/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_heif_encoder/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_keep/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_keep/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_png_filter/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_png_filter/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_subsample/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_subsample/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_tiff_compression/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_tiff_compression/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_tiff_predictor/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_tiff_predictor/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_tiff_resunit/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_tiff_resunit/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_webp_preset/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_webp_preset/0"},{"type":"type","title":"Vix.Vips.Operation.vips_intent/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_intent/0"},{"type":"type","title":"Vix.Vips.Operation.vips_interesting/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_interesting/0"},{"type":"type","title":"Vix.Vips.Operation.vips_interpretation/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_interpretation/0"},{"type":"type","title":"Vix.Vips.Operation.vips_kernel/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_kernel/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_boolean/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_boolean/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_complex2/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_complex2/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_complex/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_complex/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_complexget/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_complexget/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_math2/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_math2/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_math/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_math/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_morphology/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_morphology/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_relational/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_relational/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_round/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_round/0"},{"type":"type","title":"Vix.Vips.Operation.vips_pcs/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_pcs/0"},{"type":"type","title":"Vix.Vips.Operation.vips_precision/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_precision/0"},{"type":"type","title":"Vix.Vips.Operation.vips_region_shrink/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_region_shrink/0"},{"type":"type","title":"Vix.Vips.Operation.vips_size/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_size/0"},{"type":"type","title":"Vix.Vips.Operation.vips_text_wrap/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_text_wrap/0"},{"type":"exception","title":"Vix.Vips.Image.Error","doc":"","ref":"Vix.Vips.Image.Error.html"},{"type":"extras","title":"Vix","doc":"# Vix\n\n[![CI](https://github.com/akash-akya/vix/actions/workflows/ci.yaml/badge.svg)](https://github.com/akash-akya/vix/actions/workflows/ci.yaml)\n[![Hex.pm](https://img.shields.io/hexpm/v/vix.svg)](https://hex.pm/packages/vix)\n[![docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/vix/)\n\nVix is an Elixir extension for the [libvips](https://libvips.github.io/libvips/) image processing library.\n\nAbout libvips from its documentation:\n\n> libvips is a [demand-driven, horizontally threaded](https://github.com/libvips/libvips/wiki/Why-is-libvips-quick) image processing library. Compared to similar libraries, [libvips runs quickly and uses little memory](https://github.com/libvips/libvips/wiki/Speed-and-memory-use).","ref":"readme.html"},{"type":"extras","title":"About Vix - Vix","doc":"Vix is a **NIF**-based bindings library for libvips.\n\n**Major Features:**\n\n* Vix can take full advantage of libvips [optimizations](https://libvips.github.io/libvips/API/current/How-it-works.md.html), such as joining operations in the pipeline and caching, since Vix is a native binding.\n* Experimental support for streaming. User can read or write images without keeping the complete image in memory. See `Vix.Vips.Image.new_from_enum/1` and `Vix.Vips.Image.write_to_stream/2`\n* Efficient interoperability (zero-copy) with other libraries, such as Nx and eVision. See `Vix.Vips.Image.new_from_binary/5` and `Vix.Vips.Image.write_to_tensor/1`\n* By default, Vix provides pre-built NIF and libvips binaries for major platforms, so don't worry about handling the libvips dependencies or compiling the NIF. Just add Vix and you are good to go! See below for more details.\n* Ergonomic bindings with auto-generated documentation for operations using vips introspection, so they always match the installed libvips version. If a newer libvips version updates `adds` or `modify` operations, you don't have to wait for Vix to be updated — bindings for the operations (along with documentation) will be available automatically.\n\nCheck [Vips operation documentation](https://hexdocs.pm/vix/Vix.Vips.Operation.html) for the list of available operations and [type specifications](https://hexdocs.pm/vix/Vix.Vips.Operation.html#types).","ref":"readme.html#about-vix"},{"type":"extras","title":"Pre-compiled NIF and libvips - Vix","doc":"Starting from v0.16.0, Vix can use either pre-built binaries or platform-provided binaries.\n\nBy default, Vix provides pre-built NIF and libvips and uses them for operations. This makes deployment and release of your application simple. No need to install any compiler toolchain or dependencies to use Vix. Pre-built libvips supports reading these formats: SVG, PNG, TIFF, JPEG, WEBP, RAW, HEIF, and GIF. If you find that the pre-built libvips is missing support for an image format, you can bring your own libvips by installing it manually and configuring Vix to use that instead. Vix makes sure to generate relevant functions and documentation based on the dependencies you bring. For example, if you install libvips with dzsave support, Vix will generate dzsave bindings for you.\n\nYou can choose this using the environmental variable, `VIX_COMPILATION_MODE`. This variable must be set during compilation and at runtime. Possible values are:\n\n* `PRECOMPILED_NIF_AND_LIBVIPS` (Default): Uses the Vix-provided NIF and libvips. No need to install any additional dependencies. Big thanks to the [sharp](https://github.com/lovell/sharp) library maintainers, which pre-compiled libvips is based on: https://github.com/lovell/sharp-libvips/.\n\n  Run the command below to generate the required `checksum.exs` file.\n\n  ```sh\n  MIX_ENV=dev mix elixir_make.checksum --all --ignore-unavailable\n  ```\n\n* `PLATFORM_PROVIDED_LIBVIPS`: Uses the platform-provided libvips. NIF will be compiled during compilation phase. Install the required build tools to compile the NIF. To build a NIF you need the following:\n\n    - libvips with development headers\n      * **macOS**: using brew `brew install libvips`\n      * **Linux**: using deb `apt install libvips-dev`\n      For more details see https://www.libvips.org/install.html\n    - `pkg-config`\n    - C compiler\n\n#### Should I use Vix or [Image](https://github.com/kipcole9/image)?\n\nVix is focused on bridging the BEAM and libvips. It tries to stay close to the libvips interface in order to support a large set of use cases, so some basic operations might feel unintuitive. [Image](https://github.com/kipcole9/image), an excellent library by [@kipcole9](https://github.com/kipcole9), builds on top of Vix and provides more Elixir-friendly wrapper functions for common operations, along with many additional features: handling Exif, Math operators, and more. And all of this is accompanied by good documentation, so for most, using `Vix` via `Image` might be better choice.","ref":"readme.html#pre-compiled-nif-and-libvips"},{"type":"extras","title":"Introduction - Vix","doc":"The easiest way to get started or explore the operations is to run the Introduction Livebook.\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Fintroduction.livemd)\n\n```elixir\n# print vips version\nIO.puts(\"Version: \" <> Vix.Vips.version())\n\n# contains image read/write functions\nalias Vix.Vips.Image\n\n# Reading an image from a file. Note that the image is not actually loaded into memory at this point.\n# `img` is an `%Image{}` struct.\n{:ok, img} = Image.new_from_file(\"~/Downloads/kitty.png\")\n\n# You can also load an image from a binary, so you can work with images without touching the file system.\n# It tries to guess the image format from the binary and uses the correct loader.\n\nbin = File.read!(\"~/Downloads/kitty.png\")\n{:ok, %Image{} = img} = Image.new_from_buffer(bin)\n\n# If you know image format beforehand, you can use the appropriate function from\n# `Vix.Vips.Operation`. For example, use `Vix.Vips.Operation.pngload_buffer/2` to load a PNG.\n\nbin = File.read!(\"~/Downloads/kitty.png\")\n{:ok, {img, _flags}} = Vix.Vips.Operation.pngload_buffer(bin)\n\n# writing an `Image` to a file.\n# Image type selected based on the image path extension. See documentation for more options\n:ok = Image.write_to_file(img, \"kitty.jpg[Q=90]\")\n\n# let's print the image dimensions\nIO.puts(\"Width: #{Image.width(img)}\")\nIO.puts(\"Height: #{Image.height(img)}\")\n\n\n# Operations\n\n# contains image processing operations\nalias Vix.Vips.Operation\n\n# getting a rectangular region from the image (crop)\n{:ok, extract_img} = Operation.extract_area(img, 100, 50, 200, 200)\n\n# create image thumbnail\n#\n# This operation is significantly faster than normal resize\n# due to several optimizations such as shrink-on-load.\n# You can read more about it in the libvips docs: https://github.com/libvips/libvips/wiki/HOWTO----Image-shrinking\n#\n# Check Vix docs for more details about several optional parameters\nwidth = 100\n{:ok, thumb} = Operation.thumbnail(\"~/Downloads/dog.jpg\", width)\n\n\n# resize the image to 400x600. `resize` function accepts scaling factor.\n# Skip `vscale` if you want to preserve aspect ratio\nhscale = 400 / Image.width(img)\nvscale = 600 / Image.height(img)\n{:ok, resized_img} = Operation.resize(img, hscale, vscale: vscale)\n\n# flip the image\n{:ok, flipped_img} = Operation.flip(img, :VIPS_DIRECTION_HORIZONTAL)\n\n# Gaussian blur\n{:ok, blurred_img} = Operation.gaussblur(img, 5)\n\n# convert the image to grayscale\n{:ok, bw_img} = Operation.colourspace(img, :VIPS_INTERPRETATION_B_W)\n\n# adding gray border\n{:ok, extended_img} =\n  Operation.embed(img, 10, 10, Image.width(img) + 20, Image.height(img) + 20,\n    extend: :VIPS_EXTEND_BACKGROUND,\n    background: [128]\n  )\n\n# rotate the image 90 degrees clockwise\n{:ok, rotated_img} = Operation.rot(img, :VIPS_ANGLE_D90)\n\n# join two images horizontally\n{:ok, main_img} = Image.new_from_file(\"~/Downloads/kitten.svg\")\n{:ok, joined_img} = Operation.join(img, main_img, :VIPS_DIRECTION_HORIZONTAL, expand: true)\n\n# render text as image\n# see https://libvips.github.io/libvips/API/current/libvips-create.html#vips-text for more details\n{:ok, {text, _}} = Operation.text(~s( Vix  is  awesome! ), dpi: 300, rgba: true)\n# add text to an image\n{:ok, img_with_text} = Operation.composite2(img, text, :VIPS_BLEND_MODE_OVER, x: 50, y: 20)","ref":"readme.html#introduction"},{"type":"extras","title":"Creating GIF - Vix","doc":"black = Operation.black!(500, 500, bands: 3)\n\n# create images with different grayscale values\nframes = Enum.map(1..255//10, fn n ->\n  Operation.linear!(black, [1], [n/255,n/255,n/255])\nend)\n\n{:ok, joined_img} = Operation.arrayjoin(frames, across: 1)\n\n# set frame delay metadata. See `Image.mutate` documentation for more details\n{:ok, joined_img} =\n  Image.mutate(joined_img, fn mut_img ->\n    frame_delay = List.duplicate(100, length(frames))\n    :ok = Vix.Vips.MutableImage.set(mut_img, \"delay\", :VipsArrayInt, frame_delay)\n  end)\n\n:ok = Operation.gifsave(joined_img, Path.expand(\"~/Downloads/bw.gif\"), \"page-height\": 500)\n```\n\nThe [libvips reference manual](https://libvips.github.io/libvips/API/current/) has more detailed documentation about the operations.","ref":"readme.html#creating-gif"},{"type":"extras","title":"Livebooks - Vix","doc":"* Livebook implementing picture language defined in [*Structural and Interpretation of Computer Programs*](https://mitpress.mit.edu/sites/default/files/sicp/index.html) section [2.2.4](https://mitpress.mit.edu/sites/default/files/sicp/full-text/book/book-Z-H-15.html#%_sec_2.2.4).\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Fpicture-language.livemd)\n\n* Creating Rainbow. Quick introduction to complex numbers and operations `mapim` and `buildlut`.\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Frainbow.livemd)\n\n* Auto correct Document Rotation. Quick introduction to Fourier Transformation, Complex planes, and Arithmetic Operations.\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Fauto_correct_rotation.livemd)","ref":"readme.html#livebooks"},{"type":"extras","title":"NIF Error Logging - Vix","doc":"Vix NIF code writes logs to stderr on certain errors. This is disabled by default. To enable logging set `nif_logger_level` to `:error`. Defaults to `:none`\n\n```elixir\nconfig :vix, nif_logger_level: :error\n```","ref":"readme.html#nif-error-logging"},{"type":"extras","title":"Installation - Vix","doc":"```elixir\ndef deps do\n  [\n    {:vix, \"~> x.x.x\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2020 Akash Hiremath\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Introduction","doc":"# Introduction\n\n```elixir\nMix.install([\n  {:kino, \"~> 0.7.0\"},\n  {:vix, \"~> 0.5\"}\n])\n```\n\n```elixir\n# print vips version\nIO.puts(\"Version: \" <> Vix.Vips.version())\n```","ref":"introduction.html"},{"type":"extras","title":"Vips Image - Introduction","doc":"All image IO operations, such as reading and writing files, are available in the `Vix.Vips.Image` module. The `Image` module also contains functions to get image attributes. Most Vips operations take a `%Vix.Vips.Image{}` struct.\n\n```elixir\nalias Vix.Vips.Image\n```\n\nReading an image from a file. Note that an image is not actually loaded into memory at this point. `img` is an `%Image{}` struct.\n\n```elixir\n{:ok, %Image{} = img} = Image.new_from_file(\"~/Downloads/kitty.png\")\n```\n\nYou can also load an image from a binary. This allows us to work with images without touching the file system. It tries to guess the image format from the binary and uses the correct loader.\n\n```elixir\nbin = File.read!(\"~/Downloads/kitty.png\")\n{:ok, %Image{} = img} = Image.new_from_buffer(bin)\n```\n\nIf you know the image format beforehand, you can use the appropriate function from `Vix.Vips.Operation`. For example, you would use `Vix.Vips.Operation.pngload_buffer/2` to load a PNG.\n\n```elixir\nbin = File.read!(\"~/Downloads/kitty.png\")\n{:ok, {img, _flags}} = Vix.Vips.Operation.pngload_buffer(bin)\n```\n\nWriting `Image` to a file. Image type selected based on the image path extension. See documentation for more options\n\n```elixir\n:ok = Image.write_to_file(img, \"kitty.jpg[Q=90]\")\n```\n\n```elixir\n# let's print image dimensions\nIO.puts(\"Width: #{Image.width(img)}\")\nIO.puts(\"Height: #{Image.height(img)}\")\n```\n\nKino supports showing images inline. We can use this to display image in the livebook.\nThis opens gate for exploratory image processing\n\n```elixir\ndefmodule VixExt do\n  alias Vix.Vips.Operation\n\n  @max_height 500\n\n  def show(%Image{} = image) do\n    height = Image.height(image)\n\n    # scale down if image height is larger than 500px\n    image =\n      if height > @max_height do\n        Operation.resize!(image, @max_height / height)\n      else\n        image\n      end\n\n    # write vips-image as png image to memory\n    {:ok, image_bin} = Image.write_to_buffer(image, \".png\")\n    Kino.render(Kino.Image.new(image_bin, \"image/png\"))\n\n    :ok\n  end\nend\n```\n\n```elixir\nimport VixExt\n\n# Let's see show in action\n\nshow(img)\n```","ref":"introduction.html#vips-image"},{"type":"extras","title":"Vips Operations - Introduction","doc":"All image processing operations are available in `Vix.Vips.Operation`\n\n```elixir\nalias Vix.Vips.Operation\n```","ref":"introduction.html#vips-operations"},{"type":"extras","title":"Crop - Introduction","doc":"Getting a rectangular region from the image\n\n```elixir\n{:ok, extract_img} = Operation.extract_area(img, 100, 50, 200, 200)\nshow(extract_img)\n```","ref":"introduction.html#crop"},{"type":"extras","title":"Thumbnail - Introduction","doc":"This operation is significantly faster than normal resize due to\nseveral optimizations such as shrink-on-load.  You can read more about\nit in the libvips docs: https://github.com/libvips/libvips/wiki/HOWTO----Image-shrinking\n\nCheck Vix docs for more details about several optional parameters\n\n```elixir\n{:ok, thumb} = Operation.thumbnail(\"~/Downloads/kitty.png\", 100)\nshow(thumb)\n```","ref":"introduction.html#thumbnail"},{"type":"extras","title":"Resize - Introduction","doc":"Resize the image to 400x600. The `resize` function accepts scaling factor.\nSkip `vscale` if you want to preserve the aspect ratio.\n\n```elixir\nhscale = 400 / Image.width(img)\nvscale = 600 / Image.height(img)\n\n{:ok, resized_img} = Operation.resize(img, hscale, vscale: vscale)\nshow(resized_img)\n```","ref":"introduction.html#resize"},{"type":"extras","title":"Flip - Introduction","doc":"```elixir\ndirection_input =\n  Kino.Input.select(\"Direction: \",\n    VIPS_DIRECTION_HORIZONTAL: \"Horizontal\",\n    VIPS_DIRECTION_VERTICAL: \"Vertical\"\n  )\n```\n\n```elixir\ndirection = Kino.Input.read(direction_input)\n\n{:ok, flipped_img} = Operation.flip(img, direction)\nshow(flipped_img)\n```","ref":"introduction.html#flip"},{"type":"extras","title":"Text - Introduction","doc":"The `text` operation takes multiple optional parameters. See [libvips documentation](https://libvips.github.io/libvips/API/current/libvips-create.html#vips-text ) for more details.\n\n```elixir\ntext_input = Kino.Input.text(\"Text: \")\n```\n\n```elixir\nstr = String.trim(Kino.Input.read(text_input))\n{:ok, {text, _}} = Operation.text(str, dpi: 300, rgba: true)\n\n# add text to an image\n{:ok, inserted_text_img} = Operation.composite2(img, text, :VIPS_BLEND_MODE_OVER, x: 50, y: 20)\n\nshow(inserted_text_img)\n```","ref":"introduction.html#text"},{"type":"extras","title":"Creating a GIF - Introduction","doc":"```elixir\nblack = Operation.black!(500, 500, bands: 3)\n\n# create images with different grayscale\nframes = Enum.map(1..255//10, fn n ->\n  Operation.linear!(black, [1], [n/255, n/255, n/255])\nend)\n\n{:ok, joined_img} = Operation.arrayjoin(frames, across: 1)\n\n{:ok, joined_img} =\n  Image.mutate(joined_img, fn mut_img ->\n    frame_delay = List.duplicate(100, length(frames))\n    :ok = Vix.Vips.MutableImage.set(mut_img, \"delay\", :VipsArrayInt, frame_delay)\n  end)\n\n:ok = Operation.gifsave(joined_img, Path.expand(\"~/Downloads/bw.gif\"), \"page-height\": 500)\n```","ref":"introduction.html#creating-a-gif"},{"type":"extras","title":"A few more operations - Introduction","doc":"```elixir\n# Gaussian blur\n{:ok, blurred_img} = Operation.gaussblur(img, 5)\nshow(blurred_img)\n\n# convert image to a grayscale image\n{:ok, bw_img} = Operation.colourspace(img, :VIPS_INTERPRETATION_B_W)\nshow(bw_img)\n\n# adding gray border\n{:ok, extended_img} =\n  Operation.embed(img, 10, 10, Image.width(img) + 20, Image.height(img) + 20,\n    extend: :VIPS_EXTEND_BACKGROUND,\n    background: [128]\n  )\n\nshow(extended_img)\n\n# rotate image 90 degrees clockwise\n{:ok, rotated_img} = Operation.rot(img, :VIPS_ANGLE_D90)\nshow(rotated_img)\n\n# join two images horizontally\n{:ok, main_img} = Image.new_from_file(\"~/Downloads/kitten.svg\")\n{:ok, joined_img} = Operation.join(img, main_img, :VIPS_DIRECTION_HORIZONTAL, expand: true)\nshow(joined_img)\n```","ref":"introduction.html#a-few-more-operations"},{"type":"extras","title":"Picture Language","doc":"# Picture Language","ref":"picture-language.html"},{"type":"extras","title":"Install dependencies - Picture Language","doc":"```elixir\nMix.install([\n  {:kino, \"~> 0.3.0\"},\n  {:vix, \"~> 0.5\"}\n])\n```\n\nDefining helper function `display` using kino so that we can show image inline\n\n```elixir\ndefmodule VixExt do\n  alias Vix.Vips.Image\n  alias Vix.Vips.Operation\n\n  @max_height 500\n\n  def show(%Image{} = image) do\n    height = Image.height(image)\n\n    # scale down if image height is larger than 500px\n    image =\n      if height > @max_height do\n        Operation.resize!(image, @max_height / height)\n      else\n        image\n      end\n\n    # write vips-image as png image to memory\n    {:ok, image_bin} = Image.write_to_buffer(image, \".png\")\n    Kino.render(Kino.Image.new(image_bin, \"image/png\"))\n\n    :ok\n  end\nend\n```","ref":"picture-language.html#install-dependencies"},{"type":"extras","title":"Picture Language - Picture Language","doc":"Implementing picture language defined in [**Structural and Interpretation of Computer Programs**](https://web.mit.edu/6.001/6.037/sicp.pdf) section [2.2.4](https://web.mit.edu/6.001/6.037/sicp.pdf#subsection.2.2.4) in Elixir using vix\n\n\n```elixir\ndefmodule Pict do\n  alias Vix.Vips.Operation, as: Op\n\n  def beside(a, b) do\n    Op.resize!(Op.join!(a, b, :VIPS_DIRECTION_HORIZONTAL), 0.5, vscale: 1)\n  end\n\n  def below(a, b) do\n    Op.resize!(Op.join!(a, b, :VIPS_DIRECTION_VERTICAL), 1, vscale: 0.5)\n  end\n\n  def vert_flip(p) do\n    Op.flip!(p, :VIPS_DIRECTION_VERTICAL)\n  end\n\n  def horz_flip(p) do\n    Op.flip!(p, :VIPS_DIRECTION_HORIZONTAL)\n  end\nend\n```\n\nImplementation of [Fig. 2.9](https://web.mit.edu/6.001/6.037/sicp.pdf#page=201)\n\n```elixir\ndefmodule PictUtils do\n  import Pict\n\n  def right_split(p, 0), do: p\n\n  def right_split(p, n) do\n    t = right_split(p, n - 1)\n    beside(p, below(t, t))\n  end\n\n  def up_split(p, 0), do: p\n\n  def up_split(p, n) do\n    t = up_split(p, n - 1)\n    below(beside(t, t), p)\n  end\n\n  def corner_split(p, 0), do: p\n\n  def corner_split(p, n) do\n    us = up_split(p, n - 1)\n    rs = right_split(p, n - 1)\n\n    beside(\n      below(beside(us, us), p),\n      below(corner_split(p, n - 1), below(rs, rs))\n    )\n  end\nend\n```\n\n```elixir\nalias Vix.Vips.Image\nimport VixExt\n\n{:ok, img} = Image.new_from_file(\"~/Downloads/kitty.png\")\nimg = PictUtils.corner_split(img, 5)\n\nright = Pict.below(img, Pict.vert_flip(img))\nleft = Pict.horz_flip(right)\nimg = Pict.beside(left, right)\n\nshow(img)\n```","ref":"picture-language.html#picture-language"},{"type":"extras","title":"Creating Rainbow  🌈","doc":"# Creating Rainbow  🌈\n\n```elixir\nMix.install([\n  {:vix, \"~> 0.22.0\"},\n  {:kino, \"~> 0.10.0\"}\n])\n```","ref":"rainbow.html"},{"type":"extras","title":"Introduction - Creating Rainbow  🌈","doc":"Libvips provides over 300 image processing operations so getting an\nintuition for what is possible, and how to combine the primitive\nimage processing operations, can be challenging.\n\nIn this notebook we look into some libvips core operations by\nworking towards a simple goal — generate a rainbow 🌈. \nThe rainbow should have a half-circular arch and a smooth blend \nbetween the colors.","ref":"rainbow.html#introduction"},{"type":"extras","title":"Generating the colors - Creating Rainbow  🌈","doc":"First, let's look into generating the rainbow colors. We need to\ngenerate the whole spectrum with the smooth blend between them.\n\nlibvips provides the `buildlut` function, which generates pointwise\nintermediate values between the provided points. `lut` here means\n**L**ook **U**p **T**able. `buildlut` takes a 1D matrix where each value\nrepresents different points in the format `[position, bands]`.\n`buildlut` will build a single-band, one-pixel-height image with a\nsmooth pointwise transition between the points. If you pass `[0, 0]`\n(at position zero pixel value is zero) `[255, 255]` (at position 255\nvalue is 255), the buildlut will return an image with pixels `0` at\nposition 0, `1` at position 1, `2` at position 2 etc, ending with\n`255` at position 255. We can think of it as a range from 0 to 255, or `0..255//1`.\n\n```elixir\nalias Vix.Vips.Image\nalias Vix.Vips.Operation\n\n# buildlut needs matrix image.\n# we can create matrix-image using `Image.new_matrix_from_array` which takes\n# list and return a vips-image which can be passed to `buildlut`\n{:ok, mat} = Image.new_matrix_from_array(2, 2, [[0, 0], [255, 255]])\n\ngradient = Operation.buildlut!(mat)\n```\n\nSwitch to attributes tab to see more details about the image.\n\nWe can see the gradient clearly if we increase the image height\n\n```elixir\nOperation.resize!(gradient, 3, vscale: 50)\n```\n\n`buildlut` accepts multiple bands as well. So we can generate gradients in grayscale or color.\n```elixir\ndefmodule Vix.KinoUtils do\n  # Utility to read color and parse hex string into list of\n  # 8-bit integers\n  def read_colors do\n    start_color = Kino.Input.color(\"Start\", default: \"#DDDD55\")\n    end_color = Kino.Input.color(\"End\", default: \"#FF2200\")\n\n    [start_color, end_color]\n    |> Kino.Layout.grid(columns: 6)\n    |> Kino.render()\n\n    start_color = read(start_color)\n    end_color = read(end_color)\n\n    {start_color, end_color}\n  end\n\n  defp read(input) do\n    \"#\" <> color = Kino.Input.read(input)\n\n    for < > do\n      String.to_integer(hex, 16)\n    end\n  end\nend\n\n# read user input\n{start_color, end_color} = Vix.KinoUtils.read_colors()\n\n{:ok, mat} =\n  Image.new_matrix_from_array(4, 2, [\n    [0 | start_color],\n    [255 | end_color]\n  ])\n\nmat\n|> Operation.buildlut!()\n|> Operation.cast!(:VIPS_FORMAT_UCHAR)\n|> Operation.resize!(3, vscale: 50)\n\n# change the `Start` and `End` colors and evaluate\n```\n\nTo generate the rainbow colors, the pixel values in RGB colour space\nwill be `[255, 0, 0] (red), [255, 165, 0] (orange) ... [143, 0, 255]\n(violet)`. We could generate these values but it is inconvenient to\njuggle all 3 bands.\n\nGenerating the colors in HSV color space we need `[0, 255, 255] (red),\n[24, 255, 255] (orange) ... [212, 255, 255] (violet)`. Which is much\nnicer to work with, since we only need to change one value.\n\n```elixir\n{:ok, mat} =\n  Image.new_matrix_from_array(4, 2, [\n    # position 0   - [0,   255, 255]\n    [0, 0, 255, 255],\n    # position 255 - [255, 255, 255]\n    [255, 255, 255, 255]\n  ])\n\ngradient = Operation.buildlut!(mat)\n\n# by default the colour space won't be HSV.\n# We make a shallow copy and set the colorspace to HSV.\n# While also setting band format to `unsigned char`\nrainbow_colors =\n  Operation.copy!(gradient,\n    band_format: :VIPS_FORMAT_UCHAR,\n    interpretation: :VIPS_INTERPRETATION_HSV\n  )\n\n# resize to make it visible\nOperation.resize!(rainbow_colors, 3, vscale: 50)\n\n# notice that the output spectrum starts from RED and ends with RED.\n# this is slightly incorrect, since rainbow ends with violet. We'll fix this later\n```","ref":"rainbow.html#generating-the-colors"},{"type":"extras","title":"Generating the Arch - Creating Rainbow  🌈","doc":"How do we generate the half circular arch? There are several way to\napproach this but we are going to use complex band format and polar\ncoordinates.","ref":"rainbow.html#generating-the-arch"},{"type":"extras","title":"Complex Numbers - Creating Rainbow  🌈","doc":"In a traditional coordinate system, a pixel’s position is represented \nby two values: its x- and y-coordinates. The x-coordinate indicates the \nhorizontal position along the width of the plane, while the y-coordinate \nindicates the vertical position along the height. The two values taken \ntogether describe a point's location on a two-dimensional (2D) plane.\n\nNow consider an operator, like the Fourier transformation. It takes a \ncoordinate pair and may output a complex number. How would we handle that? \n\nIt turns out that even though a complex number is a single value, it still \nconsists of two components: a **Real** number and an **Imaginary** number. \nLike the x-coordinate above, the **Real** number component of a complex number\nindicates the horizontal position along the width of the plane. An **Imaginary** \nnumber technically represents how many units, i, a point is located off a 2D plane, \nbut for our purposes, we treat it the way we would a y-coordinate.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\nThere are two different ways to locate a point on 2D plane\n\n* Cartesian coordinate system\n* Polar coordinate system\n\n**Cartesian coordinate System**\n\nHere real part represent x coordinate and imaginary part represents y coordinate.\n\n![](images/Complex_number_illustration.png)\n\n`a` and `b` is used to locate the point `z`\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n**Polar System**\n\nHere real part represents distance from the origin and imaginary part represents angle\n\n![](images/Complex_number_illustration_modarg.png)\n\nAngle `φ` and distance `r` is used to locate point `z`\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n**But why do we need complex number?**\n\nBecause it makes certain operations simple. Operations which operate\non plane rather than axis. For example, to draw a circle on a polar\nplane we only need to vary angle keeping the distance constant.\n\nLet's do an example to see how libvips operations work on the complex\nnumber plane. First, let's create an image that has an origin in the center of\nthe image. It makes it easy to understand what is happening.\n\n```elixir\nuse Vix.Operator\n\nwidth = height = 255\n\n# create 200 x 200 matrix where each pixel represent its own position.\n# pixel at left-top will be `{0, 0}` (black)\n# pixel right-bottom will be `{255, 255}` (white)\nxy = Operation.xyz!(width, height)\n\n# Display how axis values are chaining\nKino.Layout.grid([Kino.Text.new(\"X-Axis\"), Kino.Text.new(\"Y-Axis\"), xy[0], xy[1]], columns: 2)\n|> Kino.render()\n\n# move origin to center of the image\nxy = (xy - [width / 2, height / 2]) * 2\n\n# Display how axis values are changing after moving the origin.\n# Notice that origin black pixel starts at top-left before\n# and at center after moving the origin\nKino.Layout.grid(\n  [Kino.Text.new(\"Centered X-Axis\"), Kino.Text.new(\"Centered Y-Axis\"), xy[0], xy[1]],\n  columns: 2\n)\n```\n\nNow that we have an image, we can see how it looks in polar plane\n\n```elixir\n# convert band format to complex number format.\n# we specify that read 2 bands to form a single complx band.\n# x axis becomes the real part of the complex number\n# y axis becomes the Imaginary part of the complex number\ncomplex_xy = Operation.copy!(xy, format: :VIPS_FORMAT_COMPLEX, bands: 1)\n\n# change the complex number plane to the polar plane.\n# vips reads a complex number and converts it to a value on the polar plane for all pixels.\n# real part will be distance from the origin\n# imaginary part will be the angle in degree\npolar_xy = Operation.complex!(complex_xy, :VIPS_OPERATION_COMPLEX_POLAR)\n\n# convert the complex number back to 2-band float image.\n# x axis is the real part of the complex number\n# y asix is the imaginary part of the complex number\nxy = Operation.copy!(polar_xy, format: :VIPS_FORMAT_FLOAT, bands: 2)\n\n# angle will be in degree (from 0 to 360), scale it back to 255\nxy = xy * [1, height / 360]\n\nKino.Layout.grid([Kino.Text.new(\"X-Axis\"), Kino.Text.new(\"Y-Axis\"), xy[0], xy[1]], columns: 2)\n```\n\nAs you can see the x-axis is the real part of the complex number, which is\ndistance from the origin, and the y-axis is the imaginary part, which is the angle.\n\nThis is much easier to understand if we draw a few lines on the input\nimage. and see how it changes in the polar plane\n\n```elixir\ndefmodule ComplexOps do\n  def to_polar(img, background \\\\ [0, 0, 0]) do\n    %{width: width, height: height} = Image.headers(img)\n    xy = Operation.xyz!(width, height)\n    xy = xy - [width / 2, height / 2]\n\n    scale = min(height, width) / width\n    xy = xy * 2 / scale\n\n    xy =\n      xy\n      |> Operation.copy!(format: :VIPS_FORMAT_COMPLEX, bands: 1)\n      |> Operation.complex!(:VIPS_OPERATION_COMPLEX_POLAR)\n      |> Operation.copy!(format: :VIPS_FORMAT_FLOAT, bands: 2)\n\n    xy = xy * [1, height / 360]\n\n    # mapim takes an input and a `map` and generates an output image\n    # where input image pixels are moved based on map.\n    #\n    # [new_x, new_y] = map[x, y]\n    # out[x, y] = img[new_x, new_y]\n    #\n    # mapim is to rotate, displace, distort, any type of spatial operations.\n    # where the pixel value (color) remain same but the position is changed.\n    Operation.mapim!(img, xy, background: background)\n  end\nend\n\nx_line = Operation.black!(10, height) + 255\ny_line = Operation.black!(width, 10) + 125\n\n# create a black image and draw 2 lines\n# an x axis at 50\n# a y axis at 50\nimg =\n  Operation.black!(width, height)\n  |> Operation.insert!(x_line, 50, 0)\n  |> Operation.insert!(y_line, 0, 50)\n\n# convert img to polar\nout = ComplexOps.to_polar(img)\n\nKino.Layout.grid([Kino.Text.new(\"Input\"), Kino.Text.new(\"Output\"), img, out], columns: 2)\n```\n\nA line on the x axis becomes a circle on the polar plane and a line on\nthe y axis becomes a line from the origin.\n\nSo to draw a rainbow circle, we just draw a rainbow line on the\nx-axis and convert that to the polar plane!\n\n```elixir\nrainbow_colors\n|> Operation.resize!(100 / 255, vscale: 400)\n|> Operation.embed!(150, 0, 600, 400)\n# wrap moves the image to origin\n|> Operation.wrap!()\n|> ComplexOps.to_polar()\n|> dbg()\n\n# select the stage on the output to see how image transforms\n:ok\n```\n\nAll that is left now is to make a few final adjustments to make it pretty\n\n```elixir\n# create colors from violet to red instead of red to red\n{:ok, mat} = Image.new_matrix_from_array(4, 2, [[0, 220, 255, 255], [255, 0, 255, 255]])\n\nrainbow_colors =\n  Operation.copy!(Operation.buildlut!(mat),\n    band_format: :VIPS_FORMAT_UCHAR,\n    interpretation: :VIPS_INTERPRETATION_HSV\n  )\n\nsky_color = [135, 100, 255]\n\nrainbow_colors\n|> Operation.resize!(100 / 255, vscale: 500)\n|> Operation.embed!(50, 0, 500, 500, background: sky_color)\n|> Operation.wrap!()\n|> ComplexOps.to_polar(sky_color)\n# take only top half of the image\n|> Operation.copy!(height: 250, width: 500)\n```","ref":"rainbow.html#complex-numbers"},{"type":"extras","title":"Auto Correct Document Rotation","doc":"# Auto Correct Document Rotation\n\n```elixir\nMix.install(\n  [\n    {:vix, \"~> 0.17.0\"},\n    {:kino, \"~> 0.9.2\"}\n  ],\n  # pre-built binaries does not support fourier transform operations\n  # since these operations depend on an additional library.\n  #\n  # Usually the platform/OS provided libvips comes with these additional library\n  # so we are telling vix to use the libvips provided by the platform\n  # and compile NIF for that. Follow platform specific libvips\n  # installation guide\n  system_env: [\n    {\"VIX_COMPILATION_MODE\", \"PLATFORM_PROVIDED_LIBVIPS\"}\n  ]\n)\n```","ref":"auto_correct_rotation.html"},{"type":"extras","title":"Introduction - Auto Correct Document Rotation","doc":"In this livebook we look into correcting the text image rotation using\nimage processing techniques such as Fourier Transformation, complex\nplanes, and arithmetic operations.\n\nThis notebook is heavily based on libvips [blog post](https://libvips.blogspot.com/2015/11/fancy-transforms.html)\nand [stack overflow answer](https://stackoverflow.com/questions/33698068/align-text-for-ocr/33707537#33707537).\n\nWe use the same image mentioned on the blog to test our implementation.\nSo let's first fetch the test image.\n\n```elixir\nalias Vix.Vips.Image\nalias Vix.Vips.Operation\n\n# import convenience math operators `+`, `-`, `*` etc.\nuse Vix.Operator\n\n# we use `:httpc` to download the image\n{:ok, _} = Application.ensure_all_started(:inets)\n{:ok, _} = Application.ensure_all_started(:ssl)\n\n# image link is from the stackoverflow question\nimage_url = 'https://i.stack.imgur.com/2q4Qr.png'\n{:ok, {{_, 200, _}, _headers, bin}} = :httpc.request(:get, {image_url, []}, [timeout: 5000], [])\n\n{:ok, img} =\n  bin\n  |> IO.iodata_to_binary()\n  |> Image.new_from_buffer()\n\n# convert 4 channel PNG image to black & white\nimg = Operation.colourspace!(img, :VIPS_INTERPRETATION_B_W)\n# skip alpha band\nimg = img[0]\n```\n\nNotice that the image is not fully vertical, orienttion is slightly off","ref":"auto_correct_rotation.html#introduction"},{"type":"extras","title":"Fourier Transformation - Auto Correct Document Rotation","doc":"An image can be expressed as sum of sine and cosine waves of varying\nmagnitudes, frequency and phase. Fourier Transform is an operation\nwhich decomposes an image into its sine and cosine components.\n\nThere are lot of resources online on this topic,\nI found [this](https://web.archive.org/web/20130513181427id_/http://sharp.bu.edu/~slehar/fourier/fourier.html#filtering)\nand [this](https://dsp.stackexchange.com/questions/1637/what-does-frequency-domain-denote-in-case-of-images/1644#1644) useful get started.\n\nLibvips has [`fwfft`](https://www.libvips.org/API/current/libvips-freqfilt.html#vips-fwfft)\nfunction for Forward Fourier Transform operation and\n[`invfft`](https://www.libvips.org/API/current/libvips-freqfilt.html#vips-invfft)\nfor Inverse Fourier Transform operation.","ref":"auto_correct_rotation.html#fourier-transformation"},{"type":"extras","title":"Fwfft - Auto Correct Document Rotation","doc":"`fwfft` returns an image with complex band format. Real part of the\nband will be the wave Amplitude, Imaginary part of the band will be the\nwave Phase. Position of the value is the frequency.\n\nSince the returned image is in Complex band format, it can not be displayed.\nTo make it visible we need convert the complex band to 2 band float, warp the\nimage to center, scale values so they are visible.\n\n```elixir\nwhite = Operation.black!(10, 200) + 255\nvert_line = Operation.embed!(white, 45, 0, 200, 200)\n\n# take fourier transform of the input image\nft = Operation.fwfft!(vert_line)\n\n# display the images, notice the band format and band count\nKino.Layout.grid(\n  [Kino.Text.new(\"Input\"), Kino.Text.new(\"Fourier Transform\"), vert_line, ft],\n  columns: 2\n)\n|> Kino.render()\n\n# convert complex number to 2 band double format\nft = Operation.copy!(ft, format: :VIPS_FORMAT_DOUBLE, bands: 2)\n\n# do logarithm scaling for the image so that points visible\n# and move the origin of the image to center\nscaled_ft =\n  ft\n  |> Operation.scale!(log: true)\n  |> Operation.wrap!()\n\n# separate amplitude and phase channels\namp = scaled_ft[0]\nphase = scaled_ft[1]\n\nKino.Layout.grid(\n  [Kino.Text.new(\"Amplitude\"), Kino.Text.new(\"Phase\"), amp, phase],\n  columns: 2\n)\n```\n\nSince all these conversion is common, libvips provides\n`spectrum` function which does all this for you.\nSpectrum computes fourier transform, takes absolute value\n(amplitude), scales and wraps the origin. It meant for\ndisplaying the Fourier Transform.\n\n```elixir\nOperation.spectrum!(vert_line)\n```\n\nLet's display fourier transform for few sample images to see how the\noutput changes. Change the number of lines and see how fourier transform changes.\n\n```elixir\nlines_count =\n  Kino.Input.number(\"Number of lines\", default: 10)\n  |> Kino.render()\n  |> Kino.Input.read()\n\n# lets create images which black and white lines\nwidth = trunc(100 / lines_count)\nblack_line = Operation.black!(width, 200)\n\n# 10 lines B&W lines\nlines =\n  [black_line, Operation.invert!(black_line)]\n  |> List.duplicate(lines_count)\n  |> List.flatten()\n\nvert_lines = Operation.arrayjoin!(lines, across: length(lines))\nhorz_lines = Operation.rot!(vert_lines, :VIPS_ANGLE_D90)\nvert_horz_lines = vert_lines + horz_lines\n\nsamples = [vert_lines, horz_lines, vert_horz_lines]\n\nsamples\n|> Enum.flat_map(fn img ->\n  [img, Operation.spectrum!(img)]\nend)\n|> Kino.Layout.grid(columns: 2)\n```\n\nAs we can see, the vertical lines in the input image produces a horizontal\nline in the fourier transform and horizontal lines in the\ninput produces to vertical line in the FT. Changing the number of lines\ndoes not change the number lines on the output image.\n\nSo if we take Fourier Transform of a perfect text image, it should have\nvertical lines and or horizontal lines exactly at 0, 90, 180, 270 degree angle,\nsince the characters and lines are either parallel or perpedicular. If the\ndocument is off by some angle then the same should be visible in the Fourier\nTransform.\n\n```elixir\nKino.Layout.grid([img, Operation.spectrum!(img)], columns: 2)\n```\n\nIndeed we can see a slightly off vertical line and horizontal\nlines. Now we just need to find the angle.","ref":"auto_correct_rotation.html#fwfft"},{"type":"extras","title":"Finding the angle - Auto Correct Document Rotation","doc":"As said before output of image of Fourier Transform will be in complex band format.\nThe real part of it is amplitude, which is what we are\nseeing as lines and there is imaginary part which is phase.\n\nThere are two different way to plot complex numbers on a 2D plane.\n\n* Cartesian (Rectangle) coordinate system\n* Polar coordinate system\n\nLibvips provides functions to convert numbers from one plane to other plane.\nIntuitively when converting from Cartesian system to Polar system,\nall vertical lines becomes the circle and horizontal lines becomes the arch/segment.\nWhich is what we used in the \"Creating Rainbow\" livebook for generating the arch.\n\nBut there is also the inverse operation. We can convert an image from Polar\nplan to Cartesian plane. The circle becomes the vertical line and the\nsegment becomes the horizontal line. **More importantly radius becomes the x-axis and\nangle becomes the y-axis.**\n\nLet's see few examples\n\n```elixir\ndefmodule ComplexOps do\n  def to_cartesian(img, background \\\\ [0, 0, 0]) do\n    %{width: width, height: height} = Image.headers(img)\n    xy = Operation.xyz!(width, height)\n\n    # normalize the y-axis to be between 0 and 360\n    xy = xy * [1, 360 / height]\n\n    xy =\n      xy\n      # read values as complex numbers\n      |> Operation.copy!(format: :VIPS_FORMAT_COMPLEX, bands: 1)\n      # convert from polar to Cartesian plane\n      |> Operation.complex!(:VIPS_OPERATION_COMPLEX_RECT)\n      # and convert back to float\n      |> Operation.copy!(format: :VIPS_FORMAT_FLOAT, bands: 2)\n\n    scale = min(width, height) / width\n    xy = xy * (scale / 2)\n    xy = xy + [width / 2, height / 2]\n\n    # mapim takes an input and a `map` and generates an output image\n    # where input image pixels are moved based on map.\n    #\n    # [new_x, new_y] = map[x, y]\n    # out[x, y] = img[new_x, new_y]\n    #\n    # mapim is to rotate, displace, distort, any type of spatial operations.\n    # where the pixel value (color) remain same but the position is changed.\n    Operation.mapim!(img, xy, background: background)\n  end\nend\n\nsamples\n|> Enum.flat_map(fn img ->\n  ft = Operation.spectrum!(img)\n  [img, ft, ComplexOps.to_cartesian(ft)]\nend)\n|> Kino.Layout.grid(columns: 3)\n```\n\n```elixir\n# for the input document\nimg\n|> Operation.spectrum!()\n|> ComplexOps.to_cartesian()\n```\n\nOnly thing left now is to find a row with maximum value.\nThe row number corresponding to the maximum value is the angle.\nLibvips has `project` function which finds the row wise and column\nwise sum and returns them as image, we can then use `max` to\nfind the maximum value and its position.\n\n```elixir\ndefmodule Utils do\n  def find_angle(cartesian) do\n    # find the row wise and column wise sum\n    # returns 2 images with respective column/row sum\n    {_columns, rows} = Operation.project!(cartesian)\n\n    # find position of the row with maximum value\n    {_, %{y: y_pos}} = Operation.max!(rows)\n\n    # convert the y position back to angle.\n    y_pos / Image.height(rows) * 360\n  end\nend\n\nsamples\n|> Enum.flat_map(fn img ->\n  ft = Operation.spectrum!(img)\n  cartesian = ComplexOps.to_cartesian(ft)\n\n  angle = Utils.find_angle(cartesian)\n  # print angle next to image\n  text = Kino.Text.new(\"\\n\\n\\n#{to_string(angle)}\")\n\n  [img, ft, cartesian, text]\nend)\n|> then(fn list ->\n  headers = ~w(Input Fourier-Transform Polar-Plane Angle) |> Enum.map(&Kino.Text.new/1)\n  headers ++ list\nend)\n|> Kino.Layout.grid(columns: 4)\n```\n\nIf there are multiple rows with same maximum values we pick one randomly.\n\nFor the input image\n\n```elixir\nft = Operation.spectrum!(img)\ncartesian = ComplexOps.to_cartesian(ft)\n\nangle = Utils.find_angle(cartesian)\n\n# since we know that angle can only be parallel or perpendicular\n# can take mod of 90\nangle = angle - trunc(angle / 90) * 90\n```","ref":"auto_correct_rotation.html#finding-the-angle"},{"type":"extras","title":"Correcting the rotation - Auto Correct Document Rotation","doc":"Putting it all together now we can rotate the image using the\ndifference as correction to fix the document\n\n```elixir\ndiff = 90 - angle\ncorrected = Operation.rotate!(img, diff)\n\nKino.Layout.grid([Kino.Text.new(\"Input\"), Kino.Text.new(\"Corrected\"), img, corrected], columns: 2)\n```","ref":"auto_correct_rotation.html#correcting-the-rotation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}